#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh...
#endif
//VERSION_1_0
GO(glAccum, vFuf)
GO(glAlphaFunc, vFuf)
GO(glBegin, vFu)
GO(glBitmap, vFiiffffp)
GO(glBlendFunc, vFuu)
GO(glCallList, vFu)
GO(glCallLists, vFiup)
GO(glClear, vFu)
GO(glClearAccum, vFffff)
GO(glClearColor, vFffff)
GO(glClearDepth, vFd)
GO(glClearIndex, vFf)
GO(glClearStencil, vFi)
GO(glClipPlane, vFup)
GO(glColor3b, vFccc)
GO(glColor3bv, vFp)
GO(glColor3d, vFddd)
GO(glColor3dv, vFp)
GO(glColor3f, vFfff)
GO(glColor3fv, vFp)
GO(glColor3i, vFiii)
GO(glColor3iv, vFp)
GO(glColor3s, vFwww)
GO(glColor3sv, vFp)
GO(glColor3ub, vFCCC)
GO(glColor3ubv, vFp)
GO(glColor3ui, vFuuu)
GO(glColor3uiv, vFp)
GO(glColor3us, vFWWW)
GO(glColor3usv, vFp)
GO(glColor4b, vFcccc)
GO(glColor4bv, vFp)
GO(glColor4d, vFdddd)
GO(glColor4dv, vFp)
GO(glColor4f, vFffff)
GO(glColor4fv, vFp)
GO(glColor4i, vFiiii)
GO(glColor4iv, vFp)
GO(glColor4s, vFwwww)
GO(glColor4sv, vFp)
GO(glColor4ub, vFCCCC)
GO(glColor4ubv, vFp)
GO(glColor4ui, vFuuuu)
GO(glColor4uiv, vFp)
GO(glColor4us, vFWWWW)
GO(glColor4usv, vFp)
GO(glColorMask, vFCCCC)
GO(glColorMaterial, vFuu)
GO(glCopyPixels, vFiiiiu)
GO(glCullFace, vFu)
GO(glDeleteLists, vFui)
GO(glDepthFunc, vFu)
GO(glDepthMask, vFC)
GO(glDepthRange, vFdd)
GO(glDisable, vFu)
GO(glDrawBuffer, vFu)
GO(glDrawPixels, vFiiuup)
GO(glEdgeFlag, vFC)
GO(glEdgeFlagv, vFp)
GO(glEnable, vFu)
GO(glEnd, vFv)
GO(glEndList, vFv)
GO(glEvalCoord1d, vFd)
GO(glEvalCoord1dv, vFp)
GO(glEvalCoord1f, vFf)
GO(glEvalCoord1fv, vFp)
GO(glEvalCoord2d, vFdd)
GO(glEvalCoord2dv, vFp)
GO(glEvalCoord2f, vFff)
GO(glEvalCoord2fv, vFp)
GO(glEvalMesh1, vFuii)
GO(glEvalMesh2, vFuiiii)
GO(glEvalPoint1, vFi)
GO(glEvalPoint2, vFii)
GO(glFeedbackBuffer, vFiup)
GO(glFinish, vFv)
GO(glFlush, vFv)
GO(glFogf, vFuf)
GO(glFogfv, vFup)
GO(glFogi, vFui)
GO(glFogiv, vFup)
GO(glFrontFace, vFu)
GO(glFrustum, vFdddddd)
GO(glGenLists, uFi)
GO(glGetBooleanv, vFup)
GO(glGetClipPlane, vFup)
GO(glGetDoublev, vFup)
GO(glGetError, uFv)
GO(glGetFloatv, vFup)
GO(glGetIntegerv, vFup)
GO(glGetLightfv, vFuup)
GO(glGetLightiv, vFuup)
GO(glGetMapdv, vFuup)
GO(glGetMapfv, vFuup)
GO(glGetMapiv, vFuup)
GO(glGetMaterialfv, vFuup)
GO(glGetMaterialiv, vFuup)
GO(glGetPixelMapfv, vFup)
GO(glGetPixelMapuiv, vFup)
GO(glGetPixelMapusv, vFup)
GO(glGetPolygonStipple, vFp)
GO(glGetString, pFu)
GO(glGetTexEnvfv, vFuup)
GO(glGetTexEnviv, vFuup)
GO(glGetTexGendv, vFuup)
GO(glGetTexGenfv, vFuup)
GO(glGetTexGeniv, vFuup)
GO(glGetTexImage, vFuiuup)
GO(glGetTexLevelParameterfv, vFuiup)
GO(glGetTexLevelParameteriv, vFuiup)
GO(glGetLevelParameterfv, vFuiup)   //some old programs have typo...
GO(glGetLevelParameteriv, vFuiup)   //some old programs have typo...
GO(glGetTexParameterfv, vFuup)
GO(glGetTexParameteriv, vFuup)
GO(glHint, vFuu)
GO(glIndexMask, vFu)
GO(glIndexd, vFd)
GO(glIndexdv, vFp)
GO(glIndexf, vFf)
GO(glIndexfv, vFp)
GO(glIndexi, vFi)
GO(glIndexiv, vFp)
GO(glIndexs, vFw)
GO(glIndexsv, vFp)
GO(glInitNames, vFv)
GO(glIsEnabled, CFu)
GO(glIsList, CFu)
GO(glLightModelf, vFuf)
GO(glLightModelfv, vFup)
GO(glLightModeli, vFui)
GO(glLightModeliv, vFup)
GO(glLightf, vFuuf)
GO(glLightfv, vFuup)
GO(glLighti, vFuui)
GO(glLightiv, vFuup)
GO(glLineStipple, vFiW)
GO(glLineWidth, vFf)
GO(glListBase, vFu)
GO(glLoadIdentity, vFv)
GO(glLoadMatrixd, vFp)
GO(glLoadMatrixf, vFp)
GO(glLoadName, vFu)
GO(glLogicOp, vFu)
GO(glMap1d, vFuddiip)
GO(glMap1f, vFuffiip)
GO(glMap2d, vFuddiiddiip)
GO(glMap2f, vFuffiiffiip)
GO(glMapGrid1d, vFidd)
GO(glMapGrid1f, vFiff)
GO(glMapGrid2d, vFiddidd)
GO(glMapGrid2f, vFiffiff)
GO(glMaterialf, vFuuf)
GO(glMaterialfv, vFuup)
GO(glMateriali, vFuui)
GO(glMaterialiv, vFuup)
GO(glMatrixMode, vFu)
GO(glMultMatrixd, vFp)
GO(glMultMatrixf, vFp)
GO(glNewList, vFuu)
GO(glNormal3b, vFccc)
GO(glNormal3bv, vFp)
GO(glNormal3d, vFddd)
GO(glNormal3dv, vFp)
GO(glNormal3f, vFfff)
GO(glNormal3fv, vFp)
GO(glNormal3i, vFiii)
GO(glNormal3iv, vFp)
GO(glNormal3s, vFwww)
GO(glNormal3sv, vFp)
GO(glOrtho, vFdddddd)
GO(glPassThrough, vFf)
GO(glPixelMapfv, vFuip)
GO(glPixelMapuiv, vFuip)
GO(glPixelMapusv, vFuip)
GO(glPixelStoref, vFuf)
GO(glPixelStorei, vFui)
GO(glPixelTransferf, vFuf)
GO(glPixelTransferi, vFui)
GO(glPixelZoom, vFff)
GO(glPointSize, vFf)
GO(glPolygonMode, vFuu)
GO(glPolygonStipple, vFp)
GO(glPopAttrib, vFv)
GO(glPopMatrix, vFv)
GO(glPopName, vFv)
GO(glPushAttrib, vFu)
GO(glPushMatrix, vFv)
GO(glPushName, vFu)
GO(glRasterPos2d, vFdd)
GO(glRasterPos2dv, vFp)
GO(glRasterPos2f, vFff)
GO(glRasterPos2fv, vFp)
GO(glRasterPos2i, vFii)
GO(glRasterPos2iv, vFp)
GO(glRasterPos2s, vFww)
GO(glRasterPos2sv, vFp)
GO(glRasterPos3d, vFddd)
GO(glRasterPos3dv, vFp)
GO(glRasterPos3f, vFfff)
GO(glRasterPos3fv, vFp)
GO(glRasterPos3i, vFiii)
GO(glRasterPos3iv, vFp)
GO(glRasterPos3s, vFwww)
GO(glRasterPos3sv, vFp)
GO(glRasterPos4d, vFdddd)
GO(glRasterPos4dv, vFp)
GO(glRasterPos4f, vFffff)
GO(glRasterPos4fv, vFp)
GO(glRasterPos4i, vFiiii)
GO(glRasterPos4iv, vFp)
GO(glRasterPos4s, vFwwww)
GO(glRasterPos4sv, vFp)
GO(glReadBuffer, vFu)
GO(glReadPixels, vFiiiiuup)
GO(glRectd, vFdddd)
GO(glRectdv, vFpp)
GO(glRectf, vFffff)
GO(glRectfv, vFpp)
GO(glRecti, vFiiii)
GO(glRectiv, vFpp)
GO(glRects, vFwwww)
GO(glRectsv, vFpp)
GO(glRenderMode, iFu)
GO(glRotated, vFdddd)
GO(glRotatef, vFffff)
GO(glScaled, vFddd)
GO(glScalef, vFfff)
GO(glScissor, vFiiii)
GO(glSelectBuffer, vFip)
GO(glShadeModel, vFu)
GO(glStencilFunc, vFuiu)
GO(glStencilMask, vFu)
GO(glStencilOp, vFuuu)
GO(glTexCoord1d, vFd)
GO(glTexCoord1dv, vFp)
GO(glTexCoord1f, vFf)
GO(glTexCoord1fv, vFp)
GO(glTexCoord1i, vFi)
GO(glTexCoord1iv, vFp)
GO(glTexCoord1s, vFw)
GO(glTexCoord1sv, vFp)
GO(glTexCoord2d, vFdd)
GO(glTexCoord2dv, vFp)
GO(glTexCoord2f, vFff)
GO(glTexCoord2fv, vFp)
GO(glTexCoord2i, vFii)
GO(glTexCoord2iv, vFp)
GO(glTexCoord2s, vFww)
GO(glTexCoord2sv, vFp)
GO(glTexCoord3d, vFddd)
GO(glTexCoord3dv, vFp)
GO(glTexCoord3f, vFfff)
GO(glTexCoord3fv, vFp)
GO(glTexCoord3i, vFiii)
GO(glTexCoord3iv, vFp)
GO(glTexCoord3s, vFwww)
GO(glTexCoord3sv, vFp)
GO(glTexCoord4d, vFdddd)
GO(glTexCoord4dv, vFp)
GO(glTexCoord4f, vFffff)
GO(glTexCoord4fv, vFp)
GO(glTexCoord4i, vFiiii)
GO(glTexCoord4iv, vFp)
GO(glTexCoord4s, vFwwww)
GO(glTexCoord4sv, vFp)
GO(glTexEnvf, vFuuf)
GO(glTexEnvfv, vFuup)
GO(glTexEnvi, vFuui)
GO(glTexEnviv, vFuup)
GO(glTexGend, vFuud)
GO(glTexGendv, vFuup)
GO(glTexGenf, vFuuf)
GO(glTexGenfv, vFuup)
GO(glTexGeni, vFuui)
GO(glTexGeniv, vFuup)
GO(glTexImage1D, vFuiiiiuup)
GO(glTexImage2D, vFuiiiiiuup)
GO(glTexParameterf, vFuuf)
GO(glTexParameterfv, vFuup)
GO(glTexParameteri, vFuui)
GO(glTexParameteriv, vFuup)
GO(glTranslated, vFddd)
GO(glTranslatef, vFfff)
GO(glVertex2d, vFdd)
GO(glVertex2dv, vFp)
GO(glVertex2f, vFff)
GO(glVertex2fv, vFp)
GO(glVertex2i, vFii)
GO(glVertex2iv, vFp)
GO(glVertex2s, vFww)
GO(glVertex2sv, vFp)
GO(glVertex3d, vFddd)
GO(glVertex3dv, vFp)
GO(glVertex3f, vFfff)
GO(glVertex3fv, vFp)
GO(glVertex3i, vFiii)
GO(glVertex3iv, vFp)
GO(glVertex3s, vFwww)
GO(glVertex3sv, vFp)
GO(glVertex4d, vFdddd)
GO(glVertex4dv, vFp)
GO(glVertex4f, vFffff)
GO(glVertex4fv, vFp)
GO(glVertex4i, vFiiii)
GO(glVertex4iv, vFp)
GO(glVertex4s, vFwwww)
GO(glVertex4sv, vFp)
GO(glViewport, vFiiii)
//VERSION_1_1
GO(glAreTexturesResident, CFipp)
GO(glArrayElement, vFi)
GO(glBindTexture, vFuu)
GO(glColorPointer, vFiuip)
GO(glCopyTexImage1D, vFuiuiiii)
GO(glCopyTexImage2D, vFuiuiiiii)
GO(glCopyTexSubImage1D, vFuiiiii)
GO(glCopyTexSubImage2D, vFuiiiiiii)
GO(glDeleteTextures, vFip)
GO(glDisableClientState, vFu)
GO(glDrawArrays, vFuii)
GO(glDrawElements, vFuiup)
GO(glEdgeFlagPointer, vFip)
GO(glEnableClientState, vFu)
GO(glGenTextures, vFip)
GO(glGetPointerv, vFuBp_)
GO(glIndexPointer, vFuip)
GO(glIndexub, vFC)
GO(glIndexubv, vFp)
GO(glInterleavedArrays, vFuip)
GO(glIsTexture, CFu)
GO(glNormalPointer, vFuip)
GO(glPolygonOffset, vFff)
GO(glPopClientAttrib, vFv)
GO(glPrioritizeTextures, vFipp)
GO(glPushClientAttrib, vFu)
GO(glTexCoordPointer, vFiuip)
GO(glTexSubImage1D, vFuiiiuup)
GO(glTexSubImage2D, vFuiiiiiuup)
GO(glVertexPointer, vFiuip)
//VERSION_1_2
GO(glBlendColor, vFffff)
GO(glBlendEquation, vFu)
GO(glColorSubTable, vFuiiuup)
GO(glColorTable, vFuuiuup)
GO(glColorTableParameterfv, vFuup)
GO(glColorTableParameteriv, vFuup)
GO(glConvolutionFilter1D, vFuuiuup)
GO(glConvolutionFilter2D, vFuuiiuup)
GO(glConvolutionParameterf, vFuuf)
GO(glConvolutionParameterfv, vFuup)
GO(glConvolutionParameteri, vFuui)
GO(glConvolutionParameteriv, vFuup)
GO(glCopyColorSubTable, vFuiiii)
GO(glCopyColorTable, vFuuiii)
GO(glCopyConvolutionFilter1D, vFuuiii)
GO(glCopyConvolutionFilter2D, vFuuiiii)
GO(glCopyTexSubImage3D, vFuiiiiiiii)
GO(glDrawRangeElements, vFuuuiup)
GO(glGetColorTable, vFuuup)
GO(glGetColorTableParameterfv, vFuup)
GO(glGetColorTableParameteriv, vFuup)
GO(glGetConvolutionFilter, vFuuup)
GO(glGetConvolutionParameterfv, vFuup)
GO(glGetConvolutionParameteriv, vFuup)
GO(glGetHistogram, vFuCuup)
GO(glGetHistogramParameterfv, vFuup)
GO(glGetHistogramParameteriv, vFuup)
GO(glGetMinmax, vFuCuup)
GO(glGetMinmaxParameterfv, vFuup)
GO(glGetMinmaxParameteriv, vFuup)
GO(glGetSeparableFilter, vFuuuppp)
GO(glHistogram, vFuiuC)
GO(glMinmax, vFuuC)
GO(glResetHistogram, vFu)
GO(glResetMinmax, vFu)
GO(glSeparableFilter2D, vFuuiiuupp)
GO(glTexImage3D, vFuiiiiiiuup)
GO(glTexSubImage3D, vFuiiiiiiiuup)
//VERSION_1_3
GO(glActiveTexture, vFu)
GO(glClientActiveTexture, vFu)
GO(glCompressedTexImage1D, vFuiuiiip)
GO(glCompressedTexImage2D, vFuiuiiiip)
GO(glCompressedTexImage3D, vFuiuiiiiip)
GO(glCompressedTexSubImage1D, vFuiiiuip)
GO(glCompressedTexSubImage2D, vFuiiiiiuip)
GO(glCompressedTexSubImage3D, vFuiiiiiiiuip)
GO(glGetCompressedTexImage, vFuip)
GO(glLoadTransposeMatrixd, vFp)
GO(glLoadTransposeMatrixf, vFp)
GO(glMultTransposeMatrixd, vFp)
GO(glMultTransposeMatrixf, vFp)
GO(glMultiTexCoord1d, vFud)
GO(glMultiTexCoord1dv, vFup)
GO(glMultiTexCoord1f, vFuf)
GO(glMultiTexCoord1fv, vFup)
GO(glMultiTexCoord1i, vFui)
GO(glMultiTexCoord1iv, vFup)
GO(glMultiTexCoord1s, vFuw)
GO(glMultiTexCoord1sv, vFup)
GO(glMultiTexCoord2d, vFudd)
GO(glMultiTexCoord2dv, vFup)
GO(glMultiTexCoord2f, vFuff)
GO(glMultiTexCoord2fv, vFup)
GO(glMultiTexCoord2i, vFuii)
GO(glMultiTexCoord2iv, vFup)
GO(glMultiTexCoord2s, vFuww)
GO(glMultiTexCoord2sv, vFup)
GO(glMultiTexCoord3d, vFuddd)
GO(glMultiTexCoord3dv, vFup)
GO(glMultiTexCoord3f, vFufff)
GO(glMultiTexCoord3fv, vFup)
GO(glMultiTexCoord3i, vFuiii)
GO(glMultiTexCoord3iv, vFup)
GO(glMultiTexCoord3s, vFuwww)
GO(glMultiTexCoord3sv, vFup)
GO(glMultiTexCoord4d, vFudddd)
GO(glMultiTexCoord4dv, vFup)
GO(glMultiTexCoord4f, vFuffff)
GO(glMultiTexCoord4fv, vFup)
GO(glMultiTexCoord4i, vFuiiii)
GO(glMultiTexCoord4iv, vFup)
GO(glMultiTexCoord4s, vFuwwww)
GO(glMultiTexCoord4sv, vFup)
GO(glSampleCoverage, vFfC)
//VERSION_1_4
GO(glBlendFuncSeparate, vFuuuu)
GO(glFogCoordPointer, vFuip)
GO(glFogCoordd, vFd)
GO(glFogCoorddv, vFp)
GO(glFogCoordf, vFf)
GO(glFogCoordfv, vFp)
GO(glMultiDrawArrays, vFuppi)
GOM(glMultiDrawElements, vFEupupi)
GO(glPointParameterf, vFuf)
GO(glPointParameterfv, vFup)
GO(glPointParameteri, vFui)
GO(glPointParameteriv, vFup)
GO(glSecondaryColor3b, vFccc)
GO(glSecondaryColor3bv, vFp)
GO(glSecondaryColor3d, vFddd)
GO(glSecondaryColor3dv, vFp)
GO(glSecondaryColor3f, vFfff)
GO(glSecondaryColor3fv, vFp)
GO(glSecondaryColor3i, vFiii)
GO(glSecondaryColor3iv, vFp)
GO(glSecondaryColor3s, vFwww)
GO(glSecondaryColor3sv, vFp)
GO(glSecondaryColor3ub, vFCCC)
GO(glSecondaryColor3ubv, vFp)
GO(glSecondaryColor3ui, vFuuu)
GO(glSecondaryColor3uiv, vFp)
GO(glSecondaryColor3us, vFWWW)
GO(glSecondaryColor3usv, vFp)
GO(glSecondaryColorPointer, vFiuip)
GO(glWindowPos2d, vFdd)
GO(glWindowPos2dv, vFp)
GO(glWindowPos2f, vFff)
GO(glWindowPos2fv, vFp)
GO(glWindowPos2i, vFii)
GO(glWindowPos2iv, vFp)
GO(glWindowPos2s, vFww)
GO(glWindowPos2sv, vFp)
GO(glWindowPos3d, vFddd)
GO(glWindowPos3dv, vFp)
GO(glWindowPos3f, vFfff)
GO(glWindowPos3fv, vFp)
GO(glWindowPos3i, vFiii)
GO(glWindowPos3iv, vFp)
GO(glWindowPos3s, vFwww)
GO(glWindowPos3sv, vFp)
//VERSION_1_5
GO(glBeginQuery, vFuu)
GO(glBindBuffer, vFuu)
GO(glBufferData, vFulpu)
GO(glBufferSubData, vFullp)
GO(glDeleteBuffers, vFip)
GO(glDeleteQueries, vFip)
GO(glEndQuery, vFu)
GO(glGenBuffers, vFip)
GO(glGenQueries, vFip)
GO(glGetBufferParameteriv, vFuup)
GO(glGetBufferPointerv, vFuuBp_)
GO(glGetBufferSubData, vFullp)
GO(glGetQueryObjectiv, vFuup)
GO(glGetQueryObjectuiv, vFuup)
GO(glGetQueryiv, vFuup)
GO(glIsBuffer, CFu)
GO(glIsQuery, CFu)
GO(glMapBuffer, pFuu)
GO(glUnmapBuffer, CFu)
//VERSION_2_0
GO(glAttachShader, vFuu)
GO(glBindAttribLocation, vFuup)
GO(glBlendEquationSeparate, vFuu)
GO(glCompileShader, vFu)
GO(glCreateProgram, uFv)
GO(glCreateShader, uFu)
GO(glDeleteProgram, vFu)
GO(glDeleteShader, vFu)
GO(glDetachShader, vFuu)
GO(glDisableVertexAttribArray, vFu)
GO(glDrawBuffers, vFip)
GO(glEnableVertexAttribArray, vFu)
GO(glGetActiveAttrib, vFuuipppp)
GO(glGetActiveUniform, vFuuipppp)
GO(glGetAttachedShaders, vFuipp)
GO(glGetAttribLocation, iFup)
GO(glGetProgramInfoLog, vFuipp)
GO(glGetProgramiv, vFuup)
GO(glGetShaderInfoLog, vFuipp)
GO(glGetShaderSource, vFuipp)
GO(glGetShaderiv, vFuup)
GO(glGetUniformLocation, iFup)
GO(glGetUniformfv, vFuip)
GO(glGetUniformiv, vFuip)
GO(glGetVertexAttribPointerv, vFuuBp_)
GO(glGetVertexAttribdv, vFuup)
GO(glGetVertexAttribfv, vFuup)
GO(glGetVertexAttribiv, vFuup)
GO(glIsProgram, CFu)
GO(glIsShader, CFu)
GO(glLinkProgram, vFu)
GOM(glShaderSource, vFEuipp)
GO(glStencilFuncSeparate, vFuuiu)
GO(glStencilMaskSeparate, vFuu)
GO(glStencilOpSeparate, vFuuuu)
GO(glUniform1f, vFif)
GO(glUniform1fv, vFiip)
GO(glUniform1i, vFii)
GO(glUniform1iv, vFiip)
GO(glUniform2f, vFiff)
GO(glUniform2fv, vFiip)
GO(glUniform2i, vFiii)
GO(glUniform2iv, vFiip)
GO(glUniform3f, vFifff)
GO(glUniform3fv, vFiip)
GO(glUniform3i, vFiiii)
GO(glUniform3iv, vFiip)
GO(glUniform4f, vFiffff)
GO(glUniform4fv, vFiip)
GO(glUniform4i, vFiiiii)
GO(glUniform4iv, vFiip)
GO(glUniformMatrix2fv, vFiiCp)
GO(glUniformMatrix3fv, vFiiCp)
GO(glUniformMatrix4fv, vFiiCp)
GO(glUseProgram, vFu)
GO(glValidateProgram, vFu)
GO(glVertexAttrib1d, vFud)
GO(glVertexAttrib1dv, vFup)
GO(glVertexAttrib1f, vFuf)
GO(glVertexAttrib1fv, vFup)
GO(glVertexAttrib1s, vFuw)
GO(glVertexAttrib1sv, vFup)
GO(glVertexAttrib2d, vFudd)
GO(glVertexAttrib2dv, vFup)
GO(glVertexAttrib2f, vFuff)
GO(glVertexAttrib2fv, vFup)
GO(glVertexAttrib2s, vFuww)
GO(glVertexAttrib2sv, vFup)
GO(glVertexAttrib3d, vFuddd)
GO(glVertexAttrib3dv, vFup)
GO(glVertexAttrib3f, vFufff)
GO(glVertexAttrib3fv, vFup)
GO(glVertexAttrib3s, vFuwww)
GO(glVertexAttrib3sv, vFup)
GO(glVertexAttrib4Nbv, vFup)
GO(glVertexAttrib4Niv, vFup)
GO(glVertexAttrib4Nsv, vFup)
GO(glVertexAttrib4Nub, vFuCCCC)
GO(glVertexAttrib4Nubv, vFup)
GO(glVertexAttrib4Nuiv, vFup)
GO(glVertexAttrib4Nusv, vFup)
GO(glVertexAttrib4bv, vFup)
GO(glVertexAttrib4d, vFudddd)
GO(glVertexAttrib4dv, vFup)
GO(glVertexAttrib4f, vFuffff)
GO(glVertexAttrib4fv, vFup)
GO(glVertexAttrib4iv, vFup)
GO(glVertexAttrib4s, vFuwwww)
GO(glVertexAttrib4sv, vFup)
GO(glVertexAttrib4ubv, vFup)
GO(glVertexAttrib4uiv, vFup)
GO(glVertexAttrib4usv, vFup)
GO(glVertexAttribPointer, vFuiuCip)
//VERSION_2_1
GO(glUniformMatrix2x3fv, vFiiCp)
GO(glUniformMatrix2x4fv, vFiiCp)
GO(glUniformMatrix3x2fv, vFiiCp)
GO(glUniformMatrix3x4fv, vFiiCp)
GO(glUniformMatrix4x2fv, vFiiCp)
GO(glUniformMatrix4x3fv, vFiiCp)
//VERSION_3_0
GO(glBeginConditionalRender, vFuu)
GO(glBeginTransformFeedback, vFu)
GO(glBindBufferBase, vFuuu)
GO(glBindBufferRange, vFuuull)
GO(glBindFragDataLocation, vFuup)
GO(glClampColor, vFuu)
GO(glClearBufferfi, vFuifi)
GO(glClearBufferfv, vFuip)
GO(glClearBufferiv, vFuip)
GO(glClearBufferuiv, vFuip)
GO(glColorMaski, vFuCCCC)
GO(glDisablei, vFuu)
GO(glEnablei, vFuu)
GO(glEndConditionalRender, vFv)
GO(glEndTransformFeedback, vFv)
GO(glGetBooleani_v, vFuup)
GO(glGetFragDataLocation, iFup)
GO(glGetIntegeri_v, vFuup)
GO(glGetStringi, tFuu)
GO(glGetTexParameterIiv, vFuup)
GO(glGetTexParameterIuiv, vFuup)
GO(glGetTransformFeedbackVarying, vFuuipppp)
GO(glGetUniformuiv, vFuip)
GO(glGetVertexAttribIiv, vFuup)
GO(glGetVertexAttribIuiv, vFuup)
GO(glIsEnabledi, CFuu)
GO(glTexParameterIiv, vFuup)
GO(glTexParameterIuiv, vFuup)
GOM(glTransformFeedbackVaryings, vFEuipu)
GO(glUniform1ui, vFiu)
GO(glUniform1uiv, vFiip)
GO(glUniform2ui, vFiuu)
GO(glUniform2uiv, vFiip)
GO(glUniform3ui, vFiuuu)
GO(glUniform3uiv, vFiip)
GO(glUniform4ui, vFiuuuu)
GO(glUniform4uiv, vFiip)
GO(glVertexAttribI1i, vFui)
GO(glVertexAttribI1iv, vFup)
GO(glVertexAttribI1ui, vFuu)
GO(glVertexAttribI1uiv, vFup)
GO(glVertexAttribI2i, vFuii)
GO(glVertexAttribI2iv, vFup)
GO(glVertexAttribI2ui, vFuuu)
GO(glVertexAttribI2uiv, vFup)
GO(glVertexAttribI3i, vFuiii)
GO(glVertexAttribI3iv, vFup)
GO(glVertexAttribI3ui, vFuuuu)
GO(glVertexAttribI3uiv, vFup)
GO(glVertexAttribI4bv, vFup)
GO(glVertexAttribI4i, vFuiiii)
GO(glVertexAttribI4iv, vFup)
GO(glVertexAttribI4sv, vFup)
GO(glVertexAttribI4ubv, vFup)
GO(glVertexAttribI4ui, vFuuuuu)
GO(glVertexAttribI4uiv, vFup)
GO(glVertexAttribI4usv, vFup)
GO(glVertexAttribIPointer, vFuiuip)
//VERSION_3_1
GO(glDrawArraysInstanced, vFuiii)
GO(glDrawElementsInstanced, vFuiupi)
GO(glPrimitiveRestartIndex, vFu)
GO(glTexBuffer, vFuuu)
//VERSION_3_2
GO(glFramebufferTexture, vFuuui)
GO(glGetBufferParameteri64v, vFuup)
GO(glGetInteger64i_v, vFuup)
//VERSION_3_3
GO(glVertexAttribDivisor, vFuu)
//VERSION_4_0
GO(glBlendEquationSeparatei, vFuuu)
GO(glBlendEquationi, vFuu)
GO(glBlendFuncSeparatei, vFuuuuu)
GO(glBlendFunci, vFuuu)
GO(glMinSampleShading, vFf)
//VERSION_4_3
GO(glInvalidateNamedFramebuffer, vFiup)
//VERSION_4_4
GO(glBindBuffersBase, vFuuip)
GOM(glBindBuffersRange, vFEuuippp)
GO(glBindImageTextures, vFuip)
GO(glBindSamplers, vFuip)
GO(glBindTextures, vFuip)
GOM(glBindVertexBuffers, vFEuippp)
GO(glBufferStorage, vFulpu)
GO(glClearTexImage, vFuiuup)
GO(glClearTexSubImage, vFuiiiiiiiuup)
//VERSION_4_5
GO(glClipControl, vFuu)
GO(glCreateTransformFeedbacks, vFip)
GO(glTransformFeedbackBufferBase, vFuuu)
GO(glTransformFeedbackBufferRange, vFuuull)
GO(glGetTransformFeedbackiv, vFuup)
GO(glGetTransformFeedbacki_v, vFuuup)
GO(glGetTransformFeedbacki64_v, vFuuup)
GO(glCreateBuffers, vFip)
GO(glNamedBufferStorage, vFulpu)
GO(glNamedBufferStorageEXT, vFulpu)
GO(glNamedBufferData, vFulpu)
GO(glNamedBufferSubData, vFullp)
GO(glCopyNamedBufferSubData, vFuulll)
GO(glClearNamedBufferData, vFuuuup)
GO(glClearNamedBufferSubData, vFuulluup)
GO(glMapNamedBuffer, pFuu)
GO(glMapNamedBufferRange, pFullu)
GO(glUnmapNamedBuffer, CFu)
GO(glFlushMappedNamedBufferRange, vFull)
GO(glGetNamedBufferParameteriv, vFuup)
GO(glGetNamedBufferParameteri64v, vFuup)
GO(glGetNamedBufferPointerv, vFuuBp_)
GO(glGetNamedBufferSubData, vFullp)
GO(glCreateFramebuffers, vFip)
GO(glNamedFramebufferRenderbuffer, vFuuuu)
GO(glNamedFramebufferParameteri, vFuui)
GO(glNamedFramebufferTexture, vFuuui)
GO(glNamedFramebufferTextureLayer, vFuuuii)
GO(glNamedFramebufferDrawBuffer, vFuu)
GO(glNamedFramebufferDrawBuffers, vFuip)
GO(glNamedFramebufferReadBuffer, vFuu)
GO(glInvalidateNamedFramebufferData, vFuip)
GO(glInvalidateNamedFramebufferSubData, vFuipiiii)
GO(glClearNamedFramebufferiv, vFuuip)
GO(glClearNamedFramebufferuiv, vFuuip)
GO(glClearNamedFramebufferfv, vFuuip)
GO(glClearNamedFramebufferfi, vFuuifi)
GO(glBlitNamedFramebuffer, vFuuiiiiiiiiuu)
GO(glCheckNamedFramebufferStatus, uFuu)
GO(glGetNamedFramebufferParameteriv, vFuup)
GO(glGetNamedFramebufferAttachmentParameteriv, vFuuup)
GO(glCreateRenderbuffers, vFip)
GO(glNamedRenderbufferStorage, vFuuii)
GO(glNamedRenderbufferStorageMultisample, vFuiuii)
GO(glGetNamedRenderbufferParameteriv, vFuup)
GO(glCreateTextures, vFuip)
GO(glTextureBuffer, vFuuu)
GO(glTextureBufferRange, vFuuull)
GO(glTextureStorage1D, vFuiui)
GO(glTextureStorage2D, vFuiuii)
GO(glTextureStorage3D, vFuiuiii)
GO(glTextureStorage2DMultisample, vFuiuiiC)
GO(glTextureStorage3DMultisample, vFuiuiiiC)
GO(glTextureSubImage1D, vFuiiiuup)
GO(glTextureSubImage2D, vFuiiiiiuup)
GO(glTextureSubImage3D, vFuiiiiiiiuup)
GO(glCompressedTextureSubImage1D, vFuiiiuip)
GO(glCompressedTextureSubImage2D, vFuiiiiiuip)
GO(glCompressedTextureSubImage3D, vFuiiiiiiiuip)
GO(glCopyTextureSubImage1D, vFuiiiii)
GO(glCopyTextureSubImage2D, vFuiiiiiii)
GO(glCopyTextureSubImage3D, vFuiiiiiiii)
GO(glTextureParameterf, vFuuf)
GO(glTextureParameterfv, vFuup)
GO(glTextureParameteri, vFuui)
GO(glTextureParameterIiv, vFuup)
GO(glTextureParameterIuiv, vFuup)
GO(glTextureParameteriv, vFuup)
GO(glGenerateTextureMipmap, vFu)
GO(glBindTextureUnit, vFuu)
GO(glGetTextureImage, vFuiuuip)
GO(glGetCompressedTextureImage, vFuiip)
GO(glGetTextureLevelParameterfv, vFuiup)
GO(glGetTextureLevelParameteriv, vFuiup)
GO(glGetTextureParameterfv, vFuup)
GO(glGetTextureParameterIiv, vFuup)
GO(glGetTextureParameterIuiv, vFuup)
GO(glGetTextureParameteriv, vFuup)
GO(glCreateVertexArrays, vFip)
GO(glDisableVertexArrayAttrib, vFuu)
GO(glEnableVertexArrayAttrib, vFuu)
GO(glVertexArrayElementBuffer, vFuu)
GO(glVertexArrayVertexBuffer, vFuuuli)
GOM(glVertexArrayVertexBuffers, vFEuuippp)
GO(glVertexArrayAttribBinding, vFuuu)
GO(glVertexArrayAttribFormat, vFuuiuCu)
GO(glVertexArrayAttribIFormat, vFuuiuu)
GO(glVertexArrayAttribLFormat, vFuuiuu)
GO(glVertexArrayBindingDivisor, vFuuu)
GO(glGetVertexArrayiv, vFuup)
GO(glGetVertexArrayIndexediv, vFuuup)
GO(glGetVertexArrayIndexed64iv, vFuuup)
GO(glCreateSamplers, vFip)
GO(glCreateProgramPipelines, vFip)
GO(glTextureBarrier, vFv)
GO(glTextureParameteriiv, vFuip)
GO(glTextureParameteriuiv, vFuip)
GO(glCreateQueries, vFuip)
GO(glGetQueryBufferObjecti64v, vFuuul)
GO(glGetQueryBufferObjectiv, vFuuul)
GO(glGetQueryBufferObjectui64v, vFuuul)
GO(glGetQueryBufferObjectuiv, vFuuul)
GO(glMemoryBarrierByRegion, vFu)
GO(glGetTextureSubImage, vFuiiiiiiiuuip)
GO(glGetCompressedTextureSubImage, vFuiiiiiiiip)
GO(glGetGraphicsResetStatus, uFv)
GO(glGetnUniformfv, vFuiip)
GO(glGetnUniformiv, vFuiip)
GO(glGetnUniformuiv, vFuiip)
GO(glReadnPixels, vFiiiiuuip)
//VERSION_4_6
GO(glSpecializeShader, vFupupp)

GO(glTexturePageCommitmentEXT, vFuiiiiiiiC)
GO(glVertexArrayVertexAttribDivisorEXT, vFuuu)

// _fini
//3DFX_tbuffer
GO(glTbufferMask3DFX, vFu)
//AMD_debug_output
GOM(glDebugMessageCallbackAMD, vFEpp)
GO(glDebugMessageEnableAMD, vFuuipC)
GO(glDebugMessageInsertAMD, vFuuuip)
GO(glGetDebugMessageLogAMD, uFuippppp)
//AMD_draw_buffers_blend
GO(glBlendEquationIndexedAMD, vFuu)
GO(glBlendEquationSeparateIndexedAMD, vFuuu)
GO(glBlendFuncIndexedAMD, vFuuu)
GO(glBlendFuncSeparateIndexedAMD, vFuuuuu)
//AMD_multi_draw_indirect
GO(glMultiDrawArraysIndirectAMD, vFupii)
GO(glMultiDrawElementsIndirectAMD, vFuupii)
//AMD_name_gen_delete
GO(glDeleteNamesAMD, vFuup)
GO(glGenNamesAMD, vFuup)
GO(glIsNameAMD, CFuu)
//AMD_performance_monitor
GO(glBeginPerfMonitorAMD, vFu)
GO(glDeletePerfMonitorsAMD, vFip)
GO(glEndPerfMonitorAMD, vFu)
GO(glGenPerfMonitorsAMD, vFip)
GO(glGetPerfMonitorCounterDataAMD, vFuuipp)
GO(glGetPerfMonitorCounterInfoAMD, vFuuup)
GO(glGetPerfMonitorCounterStringAMD, vFuuipp)
GO(glGetPerfMonitorCountersAMD, vFuppip)
GO(glGetPerfMonitorGroupStringAMD, vFuipp)
GO(glGetPerfMonitorGroupsAMD, vFpip)
GO(glSelectPerfMonitorCountersAMD, vFuCuip)
//AMD_sample_positions
GO(glSetMultisamplefvAMD, vFuup)
//AMD_sparse_texture
GO(glTexStorageSparseAMD, vFuuiiiiu)
GO(glTextureStorageSparseAMD, vFuuuiiiiu)
//AMD_stencil_operation_extended
GO(glStencilOpValueAMD, vFuu)
//AMD_vertex_shader_tessellator
GO(glTessellationFactorAMD, vFf)
GO(glTessellationModeAMD, vFu)
//APPLE_element_array
GO(glDrawElementArrayAPPLE, vFuii)
GO(glDrawRangeElementArrayAPPLE, vFuuuii)
GO(glElementPointerAPPLE, vFup)
GO(glMultiDrawElementArrayAPPLE, vFuppi)
GO(glMultiDrawRangeElementArrayAPPLE, vFuuuppi)
//APPLE_fence
GO(glDeleteFencesAPPLE, vFip)
GO(glFinishFenceAPPLE, vFu)
GO(glFinishObjectAPPLE, vFui)
GO(glGenFencesAPPLE, vFip)
GO(glIsFenceAPPLE, CFu)
GO(glSetFenceAPPLE, vFu)
GO(glTestFenceAPPLE, CFu)
GO(glTestObjectAPPLE, CFuu)
//APPLE_flush_buffer_range
GO(glBufferParameteriAPPLE, vFuui)
GO(glFlushMappedBufferRangeAPPLE, vFull)
//APPLE_object_purgeable
GO(glGetObjectParameterivAPPLE, vFuuup)
GO(glObjectPurgeableAPPLE, uFuuu)
GO(glObjectUnpurgeableAPPLE, uFuuu)
//APPLE_texture_range
GO(glGetTexParameterPointervAPPLE, vFuuBp_)
GO(glTextureRangeAPPLE, vFuip)
//APPLE_vertex_array_object
GO(glBindVertexArrayAPPLE, vFu)
GO(glDeleteVertexArraysAPPLE, vFip)
GO(glGenVertexArraysAPPLE, vFip)
GO(glIsVertexArrayAPPLE, CFu)
//APPLE_vertex_array_range
GO(glFlushVertexArrayRangeAPPLE, vFip)
GO(glVertexArrayParameteriAPPLE, vFui)
GO(glVertexArrayRangeAPPLE, vFip)
//APPLE_vertex_program_evaluators
GO(glDisableVertexAttribAPPLE, vFuu)
GO(glEnableVertexAttribAPPLE, vFuu)
GO(glIsVertexAttribEnabledAPPLE, CFuu)
GO(glMapVertexAttrib1dAPPLE, vFuuddiip)
GO(glMapVertexAttrib1fAPPLE, vFuuffiip)
GO(glMapVertexAttrib2dAPPLE, vFuuddiiddiip)
GO(glMapVertexAttrib2fAPPLE, vFuuffiiffiip)
//ARB_ES2_compatibility
GO(glClearDepthf, vFf)
GO(glDepthRangef, vFff)
GO(glGetShaderPrecisionFormat, vFuupp)
GO(glReleaseShaderCompiler, vFv)
GO(glShaderBinary, vFipupi)
//ARB_base_instance
GO(glDrawArraysInstancedBaseInstance, vFuiiiu)
GO(glDrawElementsInstancedBaseInstance, vFuiupiu)
GO(glDrawElementsInstancedBaseVertexBaseInstance, vFuiupiiu)
//ARB_blend_func_extended
GO(glBindFragDataLocationIndexed, vFuuup)
GO(glGetFragDataIndex, iFup)
//ARB_cl_event
GO(glCreateSyncFromCLeventARB, pFppu)
//ARB_clear_buffer_object
GO(glClearBufferData, vFuuuup)
GO(glClearBufferSubData, vFuulluup)
GO(glClearNamedBufferDataEXT, vFuuuup)
GO(glClearNamedBufferSubDataEXT, vFuulluup)
//ARB_color_buffer_float
GO(glClampColorARB, vFuu)
//ARB_compute_shader
GO(glDispatchCompute, vFuuu)
GO(glDispatchComputeIndirect, vFl)
//ARB_copy_buffer
GO(glCopyBufferSubData, vFuulll)
//ARB_copy_image
GO(glCopyImageSubData, vFuuiiiiuuiiiiiii)
//ARB_debug_output
GOM(glDebugMessageCallbackARB, vFEpp)
GO(glDebugMessageControlARB, vFuuuipC)
GO(glDebugMessageInsertARB, vFuuuuip)
GO(glGetDebugMessageLogARB, uFuipppppp)
//ARB_draw_buffers
GO(glDrawBuffersARB, vFip)
//ARB_draw_buffers_blend
GO(glBlendEquationSeparateiARB, vFuuu)
GO(glBlendEquationiARB, vFuu)
GO(glBlendFuncSeparateiARB, vFuuuuu)
GO(glBlendFunciARB, vFuuu)
//ARB_draw_elements_base_vertex
GO(glDrawElementsBaseVertex, vFuiupi)
GO(glDrawElementsInstancedBaseVertex, vFuiupii)
GO(glDrawRangeElementsBaseVertex, vFuuuiupi)
GOM(glMultiDrawElementsBaseVertex, vFEupupip)
//ARB_draw_indirect
GO(glDrawArraysIndirect, vFup)
GO(glDrawElementsIndirect, vFuup)
//ARB_draw_instanced
GO(glDrawArraysInstancedARB, vFuiii)
GO(glDrawElementsInstancedARB, vFuiupi)
//ARB_framebuffer_no_attachments
GO(glFramebufferParameteri, vFuui)
GO(glGetFramebufferParameteriv, vFuup)
GO(glGetNamedFramebufferParameterivEXT, vFuup)
GO(glNamedFramebufferParameteriEXT, vFuui)
//ARB_framebuffer_object
GO(glBindFramebuffer, vFuu)
GO(glBindRenderbuffer, vFuu)
GO(glBlitFramebuffer, vFiiiiiiiiuu)
GO(glCheckFramebufferStatus, uFu)
GO(glDeleteFramebuffers, vFip)
GO(glDeleteRenderbuffers, vFip)
GO(glFramebufferRenderbuffer, vFuuuu)
GO(glFramebufferTexture1D, vFuuuui)
GO(glFramebufferTexture2D, vFuuuui)
GO(glFramebufferTexture3D, vFuuuuii)
GO(glFramebufferTextureLayer, vFuuuii)
GO(glGenFramebuffers, vFip)
GO(glGenRenderbuffers, vFip)
GO(glGenerateMipmap, vFu)
GO(glGetFramebufferAttachmentParameteriv, vFuuup)
GO(glGetRenderbufferParameteriv, vFuup)
GO(glIsFramebuffer, CFu)
GO(glIsRenderbuffer, CFu)
GO(glRenderbufferStorage, vFuuii)
GO(glRenderbufferStorageMultisample, vFuiuii)
//ARB_geometry_shader4
GO(glFramebufferTextureARB, vFuuui)
GO(glFramebufferTextureFaceARB, vFuuuiu)
GO(glFramebufferTextureLayerARB, vFuuuii)
GO(glProgramParameteriARB, vFuui)
//ARB_get_program_binary
GO(glGetProgramBinary, vFuippp)
GO(glProgramBinary, vFuupi)
GO(glProgramParameteri, vFuui)
//ARB_gpu_shader_fp64
GO(glGetUniformdv, vFuip)
GO(glUniform1d, vFid)
GO(glUniform1dv, vFiip)
GO(glUniform2d, vFidd)
GO(glUniform2dv, vFiip)
GO(glUniform3d, vFiddd)
GO(glUniform3dv, vFiip)
GO(glUniform4d, vFidddd)
GO(glUniform4dv, vFiip)
GO(glUniformMatrix2dv, vFiiCp)
GO(glUniformMatrix2x3dv, vFiiCp)
GO(glUniformMatrix2x4dv, vFiiCp)
GO(glUniformMatrix3dv, vFiiCp)
GO(glUniformMatrix3x2dv, vFiiCp)
GO(glUniformMatrix3x4dv, vFiiCp)
GO(glUniformMatrix4dv, vFiiCp)
GO(glUniformMatrix4x2dv, vFiiCp)
GO(glUniformMatrix4x3dv, vFiiCp)
//ARB_instanced_arrays
GO(glVertexAttribDivisorARB, vFuu)
//ARB_internalformat_query
GO(glGetInternalformativ, vFuuuip)
//ARB_internalformat_query2
GO(glGetInternalformati64v, vFuuuip)
//ARB_invalidate_subdata
GO(glInvalidateBufferData, vFu)
GO(glInvalidateBufferSubData, vFull)
GO(glInvalidateFramebuffer, vFuip)
GO(glInvalidateSubFramebuffer, vFuipiiii)
GO(glInvalidateTexImage, vFui)
GO(glInvalidateTexSubImage, vFuiiiiiii)
//ARB_map_buffer_range
GO(glFlushMappedBufferRange, vFull)
GO(glMapBufferRange, pFullu)
//ARB_matrix_palette
GO(glCurrentPaletteMatrixARB, vFi)
GO(glMatrixIndexPointerARB, vFiuip)
GO(glMatrixIndexubvARB, vFip)
GO(glMatrixIndexuivARB, vFip)
GO(glMatrixIndexusvARB, vFip)
//ARB_multi_draw_indirect
GO(glMultiDrawArraysIndirect, vFupii)
GO(glMultiDrawElementsIndirect, vFuupii)
//ARB_multisample
GO(glSampleCoverageARB, vFfC)
//ARB_multitexture
GO(glActiveTextureARB, vFu)
GO(glClientActiveTextureARB, vFu)
GO(glMultiTexCoord1dARB, vFud)
GO(glMultiTexCoord1dvARB, vFup)
GO(glMultiTexCoord1fARB, vFuf)
GO(glMultiTexCoord1fvARB, vFup)
GO(glMultiTexCoord1iARB, vFui)
GO(glMultiTexCoord1ivARB, vFup)
GO(glMultiTexCoord1sARB, vFuw)
GO(glMultiTexCoord1svARB, vFup)
GO(glMultiTexCoord2dARB, vFudd)
GO(glMultiTexCoord2dvARB, vFup)
GO(glMultiTexCoord2fARB, vFuff)
GO(glMultiTexCoord2fvARB, vFup)
GO(glMultiTexCoord2iARB, vFuii)
GO(glMultiTexCoord2ivARB, vFup)
GO(glMultiTexCoord2sARB, vFuww)
GO(glMultiTexCoord2svARB, vFup)
GO(glMultiTexCoord3dARB, vFuddd)
GO(glMultiTexCoord3dvARB, vFup)
GO(glMultiTexCoord3fARB, vFufff)
GO(glMultiTexCoord3fvARB, vFup)
GO(glMultiTexCoord3iARB, vFuiii)
GO(glMultiTexCoord3ivARB, vFup)
GO(glMultiTexCoord3sARB, vFuwww)
GO(glMultiTexCoord3svARB, vFup)
GO(glMultiTexCoord4dARB, vFudddd)
GO(glMultiTexCoord4dvARB, vFup)
GO(glMultiTexCoord4fARB, vFuffff)
GO(glMultiTexCoord4fvARB, vFup)
GO(glMultiTexCoord4iARB, vFuiiii)
GO(glMultiTexCoord4ivARB, vFup)
GO(glMultiTexCoord4sARB, vFuwwww)
GO(glMultiTexCoord4svARB, vFup)
//ARB_occlusion_query
GO(glBeginQueryARB, vFuu)
GO(glDeleteQueriesARB, vFip)
GO(glEndQueryARB, vFu)
GO(glGenQueriesARB, vFip)
GO(glGetQueryObjectivARB, vFuup)
GO(glGetQueryObjectuivARB, vFuup)
GO(glGetQueryivARB, vFuup)
GO(glIsQueryARB, CFu)
//ARB_point_parameters
GO(glPointParameterfARB, vFuf)
GO(glPointParameterfvARB, vFup)
//ARB_program_interface_query
GO(glGetProgramInterfaceiv, vFuuup)
GO(glGetProgramResourceIndex, uFuup)
GO(glGetProgramResourceLocation, iFuup)
GO(glGetProgramResourceLocationIndex, iFuup)
GO(glGetProgramResourceName, vFuuuipp)
GO(glGetProgramResourceiv, vFuuuipipp)
//ARB_provoking_vertex
GO(glProvokingVertex, vFu)
//ARB_robustness
GO(glGetGraphicsResetStatusARB, uFv)
GO(glGetnColorTableARB, vFuuuip)
GO(glGetnCompressedTexImageARB, vFuiip)
GO(glGetnConvolutionFilterARB, vFuuuip)
GO(glGetnHistogramARB, vFuCuuip)
GO(glGetnMapdvARB, vFuuip)
GO(glGetnMapfvARB, vFuuip)
GO(glGetnMapivARB, vFuuip)
GO(glGetnMinmaxARB, vFuCuuip)
GO(glGetnPixelMapfvARB, vFuip)
GO(glGetnPixelMapuivARB, vFuip)
GO(glGetnPixelMapusvARB, vFuip)
GO(glGetnPolygonStippleARB, vFip)
GO(glGetnSeparableFilterARB, vFuuuipipp)
GO(glGetnTexImageARB, vFuiuuip)
GO(glGetnUniformdvARB, vFuiip)
GO(glGetnUniformfvARB, vFuiip)
GO(glGetnUniformivARB, vFuiip)
GO(glGetnUniformuivARB, vFuiip)
GO(glReadnPixelsARB, vFiiiiuuip)
//ARB_sample_shading
GO(glMinSampleShadingARB, vFf)
//ARB_sampler_objects
GO(glBindSampler, vFuu)
GO(glDeleteSamplers, vFip)
GO(glGenSamplers, vFip)
GO(glGetSamplerParameterIiv, vFuup)
GO(glGetSamplerParameterIuiv, vFuup)
GO(glGetSamplerParameterfv, vFuup)
GO(glGetSamplerParameteriv, vFuup)
GO(glIsSampler, CFu)
GO(glSamplerParameterIiv, vFuup)
GO(glSamplerParameterIuiv, vFuup)
GO(glSamplerParameterf, vFuuf)
GO(glSamplerParameterfv, vFuup)
GO(glSamplerParameteri, vFuui)
GO(glSamplerParameteriv, vFuup)
//ARB_separate_shader_objects
GO(glActiveShaderProgram, vFuu)
GO(glBindProgramPipeline, vFu)
GOM(glCreateShaderProgramv, uFEuip)
GO(glDeleteProgramPipelines, vFip)
GO(glGenProgramPipelines, vFip)
GO(glGetProgramPipelineInfoLog, vFuipp)
GO(glGetProgramPipelineiv, vFuup)
GO(glIsProgramPipeline, CFu)
GO(glProgramUniform1d, vFuid)
GO(glProgramUniform1dv, vFuiip)
GO(glProgramUniform1f, vFuif)
GO(glProgramUniform1fv, vFuiip)
GO(glProgramUniform1i, vFuii)
GO(glProgramUniform1iv, vFuiip)
GO(glProgramUniform1ui, vFuiu)
GO(glProgramUniform1uiv, vFuiip)
GO(glProgramUniform2d, vFuidd)
GO(glProgramUniform2dv, vFuiip)
GO(glProgramUniform2f, vFuiff)
GO(glProgramUniform2fv, vFuiip)
GO(glProgramUniform2i, vFuiii)
GO(glProgramUniform2iv, vFuiip)
GO(glProgramUniform2ui, vFuiuu)
GO(glProgramUniform2uiv, vFuiip)
GO(glProgramUniform3d, vFuiddd)
GO(glProgramUniform3dv, vFuiip)
GO(glProgramUniform3f, vFuifff)
GO(glProgramUniform3fv, vFuiip)
GO(glProgramUniform3i, vFuiiii)
GO(glProgramUniform3iv, vFuiip)
GO(glProgramUniform3ui, vFuiuuu)
GO(glProgramUniform3uiv, vFuiip)
GO(glProgramUniform4d, vFuidddd)
GO(glProgramUniform4dv, vFuiip)
GO(glProgramUniform4f, vFuiffff)
GO(glProgramUniform4fv, vFuiip)
GO(glProgramUniform4i, vFuiiiii)
GO(glProgramUniform4iv, vFuiip)
GO(glProgramUniform4ui, vFuiuuuu)
GO(glProgramUniform4uiv, vFuiip)
GO(glProgramUniformMatrix2dv, vFuiiCp)
GO(glProgramUniformMatrix2fv, vFuiiCp)
GO(glProgramUniformMatrix2x3dv, vFuiiCp)
GO(glProgramUniformMatrix2x3fv, vFuiiCp)
GO(glProgramUniformMatrix2x4dv, vFuiiCp)
GO(glProgramUniformMatrix2x4fv, vFuiiCp)
GO(glProgramUniformMatrix3dv, vFuiiCp)
GO(glProgramUniformMatrix3fv, vFuiiCp)
GO(glProgramUniformMatrix3x2dv, vFuiiCp)
GO(glProgramUniformMatrix3x2fv, vFuiiCp)
GO(glProgramUniformMatrix3x4dv, vFuiiCp)
GO(glProgramUniformMatrix3x4fv, vFuiiCp)
GO(glProgramUniformMatrix4dv, vFuiiCp)
GO(glProgramUniformMatrix4fv, vFuiiCp)
GO(glProgramUniformMatrix4x2dv, vFuiiCp)
GO(glProgramUniformMatrix4x2fv, vFuiiCp)
GO(glProgramUniformMatrix4x3dv, vFuiiCp)
GO(glProgramUniformMatrix4x3fv, vFuiiCp)
GO(glUseProgramStages, vFuuu)
GO(glValidateProgramPipeline, vFu)
//ARB_shader_atomic_counters
GO(glGetActiveAtomicCounterBufferiv, vFuuup)
//ARB_shader_image_load_store
GO(glBindImageTexture, vFuuiCiuu)
GO(glMemoryBarrier, vFu)
//ARB_shader_objects
GO(glAttachObjectARB, vFuu)
GO(glCompileShaderARB, vFu)
GO(glCreateProgramObjectARB, uFv)
GO(glCreateShaderObjectARB, uFu)
GO(glDeleteObjectARB, vFu)
GO(glDetachObjectARB, vFuu)
GO(glGetActiveUniformARB, vFuuipppp)
GO(glGetAttachedObjectsARB, vFuipp)
GO(glGetHandleARB, uFu)
GO(glGetInfoLogARB, vFuipp)
GO(glGetObjectParameterfvARB, vFuup)
GO(glGetObjectParameterivARB, vFuup)
GO(glGetShaderSourceARB, vFuipp)
GO(glGetUniformLocationARB, iFup)
GO(glGetUniformfvARB, vFuip)
GO(glGetUniformivARB, vFuip)
GO(glLinkProgramARB, vFu)
GOM(glShaderSourceARB, vFEuipp)
GO(glUniform1fARB, vFif)
GO(glUniform1fvARB, vFiip)
GO(glUniform1iARB, vFii)
GO(glUniform1ivARB, vFiip)
GO(glUniform2fARB, vFiff)
GO(glUniform2fvARB, vFiip)
GO(glUniform2iARB, vFiii)
GO(glUniform2ivARB, vFiip)
GO(glUniform3fARB, vFifff)
GO(glUniform3fvARB, vFiip)
GO(glUniform3iARB, vFiiii)
GO(glUniform3ivARB, vFiip)
GO(glUniform4fARB, vFiffff)
GO(glUniform4fvARB, vFiip)
GO(glUniform4iARB, vFiiiii)
GO(glUniform4ivARB, vFiip)
GO(glUniformMatrix2fvARB, vFiiCp)
GO(glUniformMatrix3fvARB, vFiiCp)
GO(glUniformMatrix4fvARB, vFiiCp)
GO(glUseProgramObjectARB, vFu)
GO(glValidateProgramARB, vFu)
//ARB_shader_storage_buffer_object
GO(glShaderStorageBlockBinding, vFuuu)
//ARB_shader_subroutine
GO(glGetActiveSubroutineName, vFuuuipp)
GO(glGetActiveSubroutineUniformName, vFuuuipp)
GO(glGetActiveSubroutineUniformiv, vFuuuup)
GO(glGetProgramStageiv, vFuuup)
GO(glGetSubroutineIndex, uFuup)
GO(glGetSubroutineUniformLocation, iFuup)
GO(glGetUniformSubroutineuiv, vFuip)
GO(glUniformSubroutinesuiv, vFuip)
//ARB_shading_language_include
GOM(glCompileShaderIncludeARB, vFEuipp)
GO(glDeleteNamedStringARB, vFip)
GO(glGetNamedStringARB, vFipipp)
GO(glGetNamedStringivARB, vFipup)
GO(glIsNamedStringARB, CFip)
GO(glNamedStringARB, vFuipip)
//ARB_sync
GO(glClientWaitSync, uFpuU)
GO(glDeleteSync, vFp)
GO(glFenceSync, pFuu)
GO(glGetInteger64v, vFup)
GO(glGetSynciv, vFpuipp)
GO(glIsSync, CFp)
GO(glWaitSync, vFpuU)
//ARB_tessellation_shader
GO(glPatchParameterfv, vFup)
GO(glPatchParameteri, vFui)
//ARB_texture_buffer_object
GO(glTexBufferARB, vFuuu)
//ARB_texture_buffer_range
GO(glTexBufferRange, vFuuull)
GO(glTextureBufferRangeEXT, vFuuuull)
//ARB_texture_compression
GO(glCompressedTexImage1DARB, vFuiuiiip)
GO(glCompressedTexImage2DARB, vFuiuiiiip)
GO(glCompressedTexImage3DARB, vFuiuiiiiip)
GO(glCompressedTexSubImage1DARB, vFuiiiuip)
GO(glCompressedTexSubImage2DARB, vFuiiiiiuip)
GO(glCompressedTexSubImage3DARB, vFuiiiiiiiuip)
GO(glGetCompressedTexImageARB, vFuip)
//ARB_texture_multisample
GO(glGetMultisamplefv, vFuup)
GO(glSampleMaski, vFuu)
GO(glTexImage2DMultisample, vFuiuiiC)
GO(glTexImage3DMultisample, vFuiuiiiC)
//ARB_texture_storage
GO(glTexStorage1D, vFuiui)
GO(glTexStorage2D, vFuiuii)
GO(glTexStorage3D, vFuiuiii)
GO(glTextureStorage1DEXT, vFuuiui)
GO(glTextureStorage2DEXT, vFuuiuii)
GO(glTextureStorage3DEXT, vFuuiuiii)
//ARB_texture_storage_multisample
GO(glTexStorage2DMultisample, vFuiuiiC)
GO(glTexStorage3DMultisample, vFuiuiiiC)
GO(glTextureStorage2DMultisampleEXT, vFuuiuiiC)
GO(glTextureStorage3DMultisampleEXT, vFuuiuiiiC)
//ARB_texture_view
GO(glTextureView, vFuuuuuuuu)
//ARB_timer_query
GO(glGetQueryObjecti64v, vFuup)
GO(glGetQueryObjectui64v, vFuup)
GO(glQueryCounter, vFuu)
//ARB_transform_feedback2
GO(glBindTransformFeedback, vFuu)
GO(glDeleteTransformFeedbacks, vFip)
GO(glDrawTransformFeedback, vFuu)
GO(glGenTransformFeedbacks, vFip)
GO(glIsTransformFeedback, CFu)
GO(glPauseTransformFeedback, vFv)
GO(glResumeTransformFeedback, vFv)
//ARB_transform_feedback3
GO(glBeginQueryIndexed, vFuuu)
GO(glDrawTransformFeedbackStream, vFuuu)
GO(glEndQueryIndexed, vFuu)
GO(glGetQueryIndexediv, vFuuup)
//ARB_transform_feedback_instanced
GO(glDrawTransformFeedbackInstanced, vFuui)
GO(glDrawTransformFeedbackStreamInstanced, vFuuui)
//ARB_transpose_matrix
GO(glLoadTransposeMatrixdARB, vFp)
GO(glLoadTransposeMatrixfARB, vFp)
GO(glMultTransposeMatrixdARB, vFp)
GO(glMultTransposeMatrixfARB, vFp)
//ARB_uniform_buffer_object
GO(glGetActiveUniformBlockName, vFuuipp)
GO(glGetActiveUniformBlockiv, vFuuup)
GO(glGetActiveUniformName, vFuuipp)
GO(glGetActiveUniformsiv, vFuipup)
GO(glGetUniformBlockIndex, uFup)
GOM(glGetUniformIndices, vFEuipp)
GO(glUniformBlockBinding, vFuuu)
//ARB_vertex_array_object
GO(glBindVertexArray, vFu)
GO(glDeleteVertexArrays, vFip)
GO(glGenVertexArrays, vFip)
GO(glIsVertexArray, CFu)
//ARB_vertex_attrib_64bit
GO(glGetVertexAttribLdv, vFuup)
GO(glVertexAttribL1d, vFud)
GO(glVertexAttribL1dv, vFup)
GO(glVertexAttribL2d, vFudd)
GO(glVertexAttribL2dv, vFup)
GO(glVertexAttribL3d, vFuddd)
GO(glVertexAttribL3dv, vFup)
GO(glVertexAttribL4d, vFudddd)
GO(glVertexAttribL4dv, vFup)
GO(glVertexAttribLPointer, vFuiuip)
//ARB_vertex_attrib_binding
GO(glBindVertexBuffer, vFuuli)
GO(glVertexArrayBindVertexBufferEXT, vFuuuli)
GO(glVertexArrayVertexAttribBindingEXT, vFuuu)
GO(glVertexArrayVertexAttribFormatEXT, vFuuiuCu)
GO(glVertexArrayVertexAttribIFormatEXT, vFuuiuu)
GO(glVertexArrayVertexAttribLFormatEXT, vFuuiuu)
GO(glVertexArrayVertexBindingDivisorEXT, vFuuu)
GO(glVertexAttribBinding, vFuu)
GO(glVertexAttribFormat, vFuiuCu)
GO(glVertexAttribIFormat, vFuiuu)
GO(glVertexAttribLFormat, vFuiuu)
GO(glVertexBindingDivisor, vFuu)
//ARB_vertex_blend
GO(glVertexBlendARB, vFi)
GO(glWeightPointerARB, vFiuip)
GO(glWeightbvARB, vFip)
GO(glWeightdvARB, vFip)
GO(glWeightfvARB, vFip)
GO(glWeightivARB, vFip)
GO(glWeightsvARB, vFip)
GO(glWeightubvARB, vFip)
GO(glWeightuivARB, vFip)
GO(glWeightusvARB, vFip)
//ARB_vertex_buffer_object
GO(glBindBufferARB, vFuu)
GO(glBufferDataARB, vFulpu)
GO(glBufferSubDataARB, vFullp)
GO(glDeleteBuffersARB, vFip)
GO(glGenBuffersARB, vFip)
GO(glGetBufferParameterivARB, vFuup)
GO(glGetBufferPointervARB, vFuubp_)
GO(glGetBufferSubDataARB, vFullp)
GO(glIsBufferARB, CFu)
GO(glMapBufferARB, pFuu)
GO(glUnmapBufferARB, CFu)
//ARB_vertex_program
GO(glBindProgramARB, vFuu)
GO(glDeleteProgramsARB, vFip)
GO(glDisableVertexAttribArrayARB, vFu)
GO(glEnableVertexAttribArrayARB, vFu)
GO(glGenProgramsARB, vFip)
GO(glGetProgramEnvParameterdvARB, vFuup)
GO(glGetProgramEnvParameterfvARB, vFuup)
GO(glGetProgramLocalParameterdvARB, vFuup)
GO(glGetProgramLocalParameterfvARB, vFuup)
GO(glGetProgramStringARB, vFuup)
GO(glGetProgramivARB, vFuup)
GO(glGetVertexAttribPointervARB, vFuuBp_)
GO(glGetVertexAttribdvARB, vFuup)
GO(glGetVertexAttribfvARB, vFuup)
GO(glGetVertexAttribivARB, vFuup)
GO(glIsProgramARB, CFu)
GO(glProgramEnvParameter4dARB, vFuudddd)
GO(glProgramEnvParameter4dvARB, vFuup)
GO(glProgramEnvParameter4fARB, vFuuffff)
GO(glProgramEnvParameter4fvARB, vFuup)
GO(glProgramLocalParameter4dARB, vFuudddd)
GO(glProgramLocalParameter4dvARB, vFuup)
GO(glProgramLocalParameter4fARB, vFuuffff)
GO(glProgramLocalParameter4fvARB, vFuup)
GO(glProgramStringARB, vFuuip)
GO(glVertexAttrib1dARB, vFud)
GO(glVertexAttrib1dvARB, vFup)
GO(glVertexAttrib1fARB, vFuf)
GO(glVertexAttrib1fvARB, vFup)
GO(glVertexAttrib1sARB, vFuw)
GO(glVertexAttrib1svARB, vFup)
GO(glVertexAttrib2dARB, vFudd)
GO(glVertexAttrib2dvARB, vFup)
GO(glVertexAttrib2fARB, vFuff)
GO(glVertexAttrib2fvARB, vFup)
GO(glVertexAttrib2sARB, vFuww)
GO(glVertexAttrib2svARB, vFup)
GO(glVertexAttrib3dARB, vFuddd)
GO(glVertexAttrib3dvARB, vFup)
GO(glVertexAttrib3fARB, vFufff)
GO(glVertexAttrib3fvARB, vFup)
GO(glVertexAttrib3sARB, vFuwww)
GO(glVertexAttrib3svARB, vFup)
GO(glVertexAttrib4NbvARB, vFup)
GO(glVertexAttrib4NivARB, vFup)
GO(glVertexAttrib4NsvARB, vFup)
GO(glVertexAttrib4NubARB, vFuCCCC)
GO(glVertexAttrib4NubvARB, vFup)
GO(glVertexAttrib4NuivARB, vFup)
GO(glVertexAttrib4NusvARB, vFup)
GO(glVertexAttrib4bvARB, vFup)
GO(glVertexAttrib4dARB, vFudddd)
GO(glVertexAttrib4dvARB, vFup)
GO(glVertexAttrib4fARB, vFuffff)
GO(glVertexAttrib4fvARB, vFup)
GO(glVertexAttrib4ivARB, vFup)
GO(glVertexAttrib4sARB, vFuwwww)
GO(glVertexAttrib4svARB, vFup)
GO(glVertexAttrib4ubvARB, vFup)
GO(glVertexAttrib4uivARB, vFup)
GO(glVertexAttrib4usvARB, vFup)
GO(glVertexAttribPointerARB, vFuiuCip)
//ARB_vertex_shader
GO(glBindAttribLocationARB, vFuup)
GO(glGetActiveAttribARB, vFuuipppp)
GO(glGetAttribLocationARB, iFup)
//ARB_vertex_type_2_10_10_10_rev
GO(glColorP3ui, vFuu)
GO(glColorP3uiv, vFup)
GO(glColorP4ui, vFuu)
GO(glColorP4uiv, vFup)
GO(glMultiTexCoordP1ui, vFuuu)
GO(glMultiTexCoordP1uiv, vFuup)
GO(glMultiTexCoordP2ui, vFuuu)
GO(glMultiTexCoordP2uiv, vFuup)
GO(glMultiTexCoordP3ui, vFuuu)
GO(glMultiTexCoordP3uiv, vFuup)
GO(glMultiTexCoordP4ui, vFuuu)
GO(glMultiTexCoordP4uiv, vFuup)
GO(glNormalP3ui, vFuu)
GO(glNormalP3uiv, vFup)
GO(glSecondaryColorP3ui, vFuu)
GO(glSecondaryColorP3uiv, vFup)
GO(glTexCoordP1ui, vFuu)
GO(glTexCoordP1uiv, vFup)
GO(glTexCoordP2ui, vFuu)
GO(glTexCoordP2uiv, vFup)
GO(glTexCoordP3ui, vFuu)
GO(glTexCoordP3uiv, vFup)
GO(glTexCoordP4ui, vFuu)
GO(glTexCoordP4uiv, vFup)
GO(glVertexAttribP1ui, vFuuCu)
GO(glVertexAttribP1uiv, vFuuCp)
GO(glVertexAttribP2ui, vFuuCu)
GO(glVertexAttribP2uiv, vFuuCp)
GO(glVertexAttribP3ui, vFuuCu)
GO(glVertexAttribP3uiv, vFuuCp)
GO(glVertexAttribP4ui, vFuuCu)
GO(glVertexAttribP4uiv, vFuuCp)
GO(glVertexP2ui, vFuu)
GO(glVertexP2uiv, vFup)
GO(glVertexP3ui, vFuu)
GO(glVertexP3uiv, vFup)
GO(glVertexP4ui, vFuu)
GO(glVertexP4uiv, vFup)
//ARB_viewport_array
GO(glDepthRangeArrayv, vFuip)
GO(glDepthRangeIndexed, vFudd)
GO(glGetDoublei_v, vFuup)
GO(glGetFloati_v, vFuup)
GO(glScissorArrayv, vFuip)
GO(glScissorIndexed, vFuiiii)
GO(glScissorIndexedv, vFup)
GO(glViewportArrayv, vFuip)
GO(glViewportIndexedf, vFuffff)
GO(glViewportIndexedfv, vFup)
//ARB_window_pos
GO(glWindowPos2dARB, vFdd)
GO(glWindowPos2dvARB, vFp)
GO(glWindowPos2fARB, vFff)
GO(glWindowPos2fvARB, vFp)
GO(glWindowPos2iARB, vFii)
GO(glWindowPos2ivARB, vFp)
GO(glWindowPos2sARB, vFww)
GO(glWindowPos2svARB, vFp)
GO(glWindowPos3dARB, vFddd)
GO(glWindowPos3dvARB, vFp)
GO(glWindowPos3fARB, vFfff)
GO(glWindowPos3fvARB, vFp)
GO(glWindowPos3iARB, vFiii)
GO(glWindowPos3ivARB, vFp)
GO(glWindowPos3sARB, vFwww)
GO(glWindowPos3svARB, vFp)
//ATI_draw_buffers
GO(glDrawBuffersATI, vFip)
//ATI_element_array
GO(glDrawElementArrayATI, vFui)
GO(glDrawRangeElementArrayATI, vFuuui)
GO(glElementPointerATI, vFup)
//ATI_envmap_bumpmap
GO(glGetTexBumpParameterfvATI, vFup)
GO(glGetTexBumpParameterivATI, vFup)
GO(glTexBumpParameterfvATI, vFup)
GO(glTexBumpParameterivATI, vFup)
//ATI_fragment_shader
GO(glAlphaFragmentOp1ATI, vFuuuuuu)
GO(glAlphaFragmentOp2ATI, vFuuuuuuuuu)
GO(glAlphaFragmentOp3ATI, vFuuuuuuuuuuuu)
GO(glBeginFragmentShaderATI, vFv)
GO(glBindFragmentShaderATI, vFu)
GO(glColorFragmentOp1ATI, vFuuuuuuu)
GO(glColorFragmentOp2ATI, vFuuuuuuuuuu)
GO(glColorFragmentOp3ATI, vFuuuuuuuuuuuuu)
GO(glDeleteFragmentShaderATI, vFu)
GO(glEndFragmentShaderATI, vFv)
GO(glGenFragmentShadersATI, uFu)
GO(glPassTexCoordATI, vFuuu)
GO(glSampleMapATI, vFuuu)
GO(glSetFragmentShaderConstantATI, vFup)
//ATI_map_object_buffer
GO(glMapObjectBufferATI, pFu)
GO(glUnmapObjectBufferATI, vFu)
//ATI_pn_triangles
GO(glPNTrianglesfATI, vFuf)
GO(glPNTrianglesiATI, vFui)
//ATI_separate_stencil
GO(glStencilFuncSeparateATI, vFuuiu)
GO(glStencilOpSeparateATI, vFuuuu)
//ATI_vertex_array_object
GO(glArrayObjectATI, vFuiuiuu)
GO(glFreeObjectBufferATI, vFu)
GO(glGetArrayObjectfvATI, vFuup)
GO(glGetArrayObjectivATI, vFuup)
GO(glGetObjectBufferfvATI, vFuup)
GO(glGetObjectBufferivATI, vFuup)
GO(glGetVariantArrayObjectfvATI, vFuup)
GO(glGetVariantArrayObjectivATI, vFuup)
GO(glIsObjectBufferATI, CFu)
GO(glNewObjectBufferATI, uFipu)
GO(glUpdateObjectBufferATI, vFuuipu)
GO(glVariantArrayObjectATI, vFuuiuu)
//ATI_vertex_attrib_array_object
GO(glGetVertexAttribArrayObjectfvATI, vFuup)
GO(glGetVertexAttribArrayObjectivATI, vFuup)
GO(glVertexAttribArrayObjectATI, vFuiuCiuu)
//ATI_vertex_streams
GO(glClientActiveVertexStreamATI, vFu)
GO(glNormalStream3bATI, vFuccc)
GO(glNormalStream3bvATI, vFup)
GO(glNormalStream3dATI, vFuddd)
GO(glNormalStream3dvATI, vFup)
GO(glNormalStream3fATI, vFufff)
GO(glNormalStream3fvATI, vFup)
GO(glNormalStream3iATI, vFuiii)
GO(glNormalStream3ivATI, vFup)
GO(glNormalStream3sATI, vFuwww)
GO(glNormalStream3svATI, vFup)
GO(glVertexBlendEnvfATI, vFuf)
GO(glVertexBlendEnviATI, vFui)
GO(glVertexStream1dATI, vFud)
GO(glVertexStream1dvATI, vFup)
GO(glVertexStream1fATI, vFuf)
GO(glVertexStream1fvATI, vFup)
GO(glVertexStream1iATI, vFui)
GO(glVertexStream1ivATI, vFup)
GO(glVertexStream1sATI, vFuw)
GO(glVertexStream1svATI, vFup)
GO(glVertexStream2dATI, vFudd)
GO(glVertexStream2dvATI, vFup)
GO(glVertexStream2fATI, vFuff)
GO(glVertexStream2fvATI, vFup)
GO(glVertexStream2iATI, vFuii)
GO(glVertexStream2ivATI, vFup)
GO(glVertexStream2sATI, vFuww)
GO(glVertexStream2svATI, vFup)
GO(glVertexStream3dATI, vFuddd)
GO(glVertexStream3dvATI, vFup)
GO(glVertexStream3fATI, vFufff)
GO(glVertexStream3fvATI, vFup)
GO(glVertexStream3iATI, vFuiii)
GO(glVertexStream3ivATI, vFup)
GO(glVertexStream3sATI, vFuwww)
GO(glVertexStream3svATI, vFup)
GO(glVertexStream4dATI, vFudddd)
GO(glVertexStream4dvATI, vFup)
GO(glVertexStream4fATI, vFuffff)
GO(glVertexStream4fvATI, vFup)
GO(glVertexStream4iATI, vFuiiii)
GO(glVertexStream4ivATI, vFup)
GO(glVertexStream4sATI, vFuwwww)
GO(glVertexStream4svATI, vFup)
//EXT_bindable_uniform
GO(glGetUniformBufferSizeEXT, iFui)
GO(glGetUniformOffsetEXT, lFui)
GO(glUniformBufferEXT, vFuiu)
//EXT_blend_color
GO(glBlendColorEXT, vFffff)
//EXT_blend_equation_separate
GO(glBlendEquationSeparateEXT, vFuu)
//EXT_blend_func_separate
GO(glBlendFuncSeparateEXT, vFuuuu)
//EXT_blend_minmax
GO(glBlendEquationEXT, vFu)
//EXT_color_subtable
GO(glColorSubTableEXT, vFuiiuup)
GO(glCopyColorSubTableEXT, vFuiiii)
//EXT_compiled_vertex_array
GO(glLockArraysEXT, vFii)
GO(glUnlockArraysEXT, vFv)
//EXT_convolution
GO(glConvolutionFilter1DEXT, vFuuiuup)
GO(glConvolutionFilter2DEXT, vFuuiiuup)
GO(glConvolutionParameterfEXT, vFuuf)
GO(glConvolutionParameterfvEXT, vFuup)
GO(glConvolutionParameteriEXT, vFuui)
GO(glConvolutionParameterivEXT, vFuup)
GO(glCopyConvolutionFilter1DEXT, vFuuiii)
GO(glCopyConvolutionFilter2DEXT, vFuuiiii)
GO(glGetConvolutionFilterEXT, vFuuup)
GO(glGetConvolutionParameterfvEXT, vFuup)
GO(glGetConvolutionParameterivEXT, vFuup)
GO(glGetSeparableFilterEXT, vFuuuppp)
GO(glSeparableFilter2DEXT, vFuuiiuupp)
//EXT_coordinate_frame
GO(glBinormal3bEXT, vFccc)
GO(glBinormal3bvEXT, vFp)
GO(glBinormal3dEXT, vFddd)
GO(glBinormal3dvEXT, vFp)
GO(glBinormal3fEXT, vFfff)
GO(glBinormal3fvEXT, vFp)
GO(glBinormal3iEXT, vFiii)
GO(glBinormal3ivEXT, vFp)
GO(glBinormal3sEXT, vFwww)
GO(glBinormal3svEXT, vFp)
GO(glBinormalPointerEXT, vFuip)
GO(glTangent3bEXT, vFccc)
GO(glTangent3bvEXT, vFp)
GO(glTangent3dEXT, vFddd)
GO(glTangent3dvEXT, vFp)
GO(glTangent3fEXT, vFfff)
GO(glTangent3fvEXT, vFp)
GO(glTangent3iEXT, vFiii)
GO(glTangent3ivEXT, vFp)
GO(glTangent3sEXT, vFwww)
GO(glTangent3svEXT, vFp)
GO(glTangentPointerEXT, vFuip)
//EXT_copy_texture
GO(glCopyTexImage1DEXT, vFuiuiiii)
GO(glCopyTexImage2DEXT, vFuiuiiiii)
GO(glCopyTexSubImage1DEXT, vFuiiiii)
GO(glCopyTexSubImage2DEXT, vFuiiiiiii)
GO(glCopyTexSubImage3DEXT, vFuiiiiiiii)
//EXT_cull_vertex
GO(glCullParameterdvEXT, vFup)
GO(glCullParameterfvEXT, vFup)
//EXT_depth_bounds_test
GO(glDepthBoundsEXT, vFdd)
//EXT_direct_state_access
GO(glBindMultiTextureEXT, vFuuu)
GO(glCheckNamedFramebufferStatusEXT, uFuu)
GO(glClientAttribDefaultEXT, vFu)
GO(glCompressedMultiTexImage1DEXT, vFuuiuiiip)
GO(glCompressedMultiTexImage2DEXT, vFuuiuiiiip)
GO(glCompressedMultiTexImage3DEXT, vFuuiuiiiiip)
GO(glCompressedMultiTexSubImage1DEXT, vFuuiiiuip)
GO(glCompressedMultiTexSubImage2DEXT, vFuuiiiiiuip)
GO(glCompressedMultiTexSubImage3DEXT, vFuuiiiiiiiuip)
GO(glCompressedTextureImage1DEXT, vFuuiuiiip)
GO(glCompressedTextureImage2DEXT, vFuuiuiiiip)
GO(glCompressedTextureImage3DEXT, vFuuiuiiiiip)
GO(glCompressedTextureSubImage1DEXT, vFuuiiiuip)
GO(glCompressedTextureSubImage2DEXT, vFuuiiiiiuip)
GO(glCompressedTextureSubImage3DEXT, vFuuiiiiiiiuip)
GO(glCopyMultiTexImage1DEXT, vFuuiuiiii)
GO(glCopyMultiTexImage2DEXT, vFuuiuiiiii)
GO(glCopyMultiTexSubImage1DEXT, vFuuiiiii)
GO(glCopyMultiTexSubImage2DEXT, vFuuiiiiiii)
GO(glCopyMultiTexSubImage3DEXT, vFuuiiiiiiii)
GO(glCopyTextureImage1DEXT, vFuuiuiiii)
GO(glCopyTextureImage2DEXT, vFuuiuiiiii)
GO(glCopyTextureSubImage1DEXT, vFuuiiiii)
GO(glCopyTextureSubImage2DEXT, vFuuiiiiiii)
GO(glCopyTextureSubImage3DEXT, vFuuiiiiiiii)
GO(glDisableClientStateIndexedEXT, vFuu)
GO(glDisableClientStateiEXT, vFuu)
GO(glDisableVertexArrayAttribEXT, vFuu)
GO(glDisableVertexArrayEXT, vFuu)
GO(glEnableClientStateIndexedEXT, vFuu)
GO(glEnableClientStateiEXT, vFuu)
GO(glEnableVertexArrayAttribEXT, vFuu)
GO(glEnableVertexArrayEXT, vFuu)
GO(glFlushMappedNamedBufferRangeEXT, vFull)
GO(glFramebufferDrawBufferEXT, vFuu)
GO(glFramebufferDrawBuffersEXT, vFuip)
GO(glFramebufferReadBufferEXT, vFuu)
GO(glGenerateMultiTexMipmapEXT, vFuu)
GO(glGenerateTextureMipmapEXT, vFuu)
GO(glGetCompressedMultiTexImageEXT, vFuuip)
GO(glGetCompressedTextureImageEXT, vFuuip)
GO(glGetDoubleIndexedvEXT, vFuup)
GO(glGetDoublei_vEXT, vFuup)
GO(glGetFloatIndexedvEXT, vFuup)
GO(glGetFloati_vEXT, vFuup)
GO(glGetFramebufferParameterivEXT, vFuup)
GO(glGetMultiTexEnvfvEXT, vFuuup)
GO(glGetMultiTexEnvivEXT, vFuuup)
GO(glGetMultiTexGendvEXT, vFuuup)
GO(glGetMultiTexGenfvEXT, vFuuup)
GO(glGetMultiTexGenivEXT, vFuuup)
GO(glGetMultiTexImageEXT, vFuuiuup)
GO(glGetMultiTexLevelParameterfvEXT, vFuuiup)
GO(glGetMultiTexLevelParameterivEXT, vFuuiup)
GO(glGetMultiTexParameterIivEXT, vFuuup)
GO(glGetMultiTexParameterIuivEXT, vFuuup)
GO(glGetMultiTexParameterfvEXT, vFuuup)
GO(glGetMultiTexParameterivEXT, vFuuup)
GO(glGetNamedBufferParameterivEXT, vFuup)
GO(glGetNamedBufferPointervEXT, vFuuBp_)
GO(glGetNamedBufferSubDataEXT, vFullp)
GO(glGetNamedFramebufferAttachmentParameterivEXT, vFuuup)
GO(glGetNamedProgramLocalParameterIivEXT, vFuuup)
GO(glGetNamedProgramLocalParameterIuivEXT, vFuuup)
GO(glGetNamedProgramLocalParameterdvEXT, vFuuup)
GO(glGetNamedProgramLocalParameterfvEXT, vFuuup)
GO(glGetNamedProgramStringEXT, vFuuup)
GO(glGetNamedProgramivEXT, vFuuup)
GO(glGetNamedRenderbufferParameterivEXT, vFuup)
GO(glGetPointerIndexedvEXT, vFuuBp_)
GO(glGetPointeri_vEXT, vFuuBp_)
GO(glGetTextureImageEXT, vFuuiuup)
GO(glGetTextureLevelParameterfvEXT, vFuuiup)
GO(glGetTextureLevelParameterivEXT, vFuuiup)
GO(glGetTextureParameterIivEXT, vFuuup)
GO(glGetTextureParameterIuivEXT, vFuuup)
GO(glGetTextureParameterfvEXT, vFuuup)
GO(glGetTextureParameterivEXT, vFuuup)
GO(glGetVertexArrayIntegeri_vEXT, vFuuup)
GO(glGetVertexArrayIntegervEXT, vFuup)
GO(glGetVertexArrayPointeri_vEXT, vFuuuBp_)
GO(glGetVertexArrayPointervEXT, vFuuBp_)
GO(glMapNamedBufferEXT, pFuu)
GO(glMapNamedBufferRangeEXT, pFullu)
GO(glMatrixFrustumEXT, vFudddddd)
GO(glMatrixLoadIdentityEXT, vFu)
GO(glMatrixLoadTransposedEXT, vFup)
GO(glMatrixLoadTransposefEXT, vFup)
GO(glMatrixLoaddEXT, vFup)
GO(glMatrixLoadfEXT, vFup)
GO(glMatrixMultTransposedEXT, vFup)
GO(glMatrixMultTransposefEXT, vFup)
GO(glMatrixMultdEXT, vFup)
GO(glMatrixMultfEXT, vFup)
GO(glMatrixOrthoEXT, vFudddddd)
GO(glMatrixPopEXT, vFu)
GO(glMatrixPushEXT, vFu)
GO(glMatrixRotatedEXT, vFudddd)
GO(glMatrixRotatefEXT, vFuffff)
GO(glMatrixScaledEXT, vFuddd)
GO(glMatrixScalefEXT, vFufff)
GO(glMatrixTranslatedEXT, vFuddd)
GO(glMatrixTranslatefEXT, vFufff)
GO(glMultiTexBufferEXT, vFuuuu)
GO(glMultiTexCoordPointerEXT, vFuiuip)
GO(glMultiTexEnvfEXT, vFuuuf)
GO(glMultiTexEnvfvEXT, vFuuup)
GO(glMultiTexEnviEXT, vFuuui)
GO(glMultiTexEnvivEXT, vFuuup)
GO(glMultiTexGendEXT, vFuuud)
GO(glMultiTexGendvEXT, vFuuup)
GO(glMultiTexGenfEXT, vFuuuf)
GO(glMultiTexGenfvEXT, vFuuup)
GO(glMultiTexGeniEXT, vFuuui)
GO(glMultiTexGenivEXT, vFuuup)
GO(glMultiTexImage1DEXT, vFuuiiiiuup)
GO(glMultiTexImage2DEXT, vFuuiiiiiuup)
GO(glMultiTexImage3DEXT, vFuuiiiiiiuup)
GO(glMultiTexParameterIivEXT, vFuuup)
GO(glMultiTexParameterIuivEXT, vFuuup)
GO(glMultiTexParameterfEXT, vFuuuf)
GO(glMultiTexParameterfvEXT, vFuuup)
GO(glMultiTexParameteriEXT, vFuuui)
GO(glMultiTexParameterivEXT, vFuuup)
GO(glMultiTexRenderbufferEXT, vFuuu)
GO(glMultiTexSubImage1DEXT, vFuuiiiuup)
GO(glMultiTexSubImage2DEXT, vFuuiiiiiuup)
GO(glMultiTexSubImage3DEXT, vFuuiiiiiiiuup)
GO(glNamedBufferDataEXT, vFulpu)
GO(glNamedBufferSubDataEXT, vFullp)
GO(glNamedCopyBufferSubDataEXT, vFuulll)
GO(glNamedFramebufferRenderbufferEXT, vFuuuu)
GO(glNamedFramebufferTexture1DEXT, vFuuuui)
GO(glNamedFramebufferTexture2DEXT, vFuuuui)
GO(glNamedFramebufferTexture3DEXT, vFuuuuii)
GO(glNamedFramebufferTextureEXT, vFuuui)
GO(glNamedFramebufferTextureFaceEXT, vFuuuiu)
GO(glNamedFramebufferTextureLayerEXT, vFuuuii)
GO(glNamedProgramLocalParameter4dEXT, vFuuudddd)
GO(glNamedProgramLocalParameter4dvEXT, vFuuup)
GO(glNamedProgramLocalParameter4fEXT, vFuuuffff)
GO(glNamedProgramLocalParameter4fvEXT, vFuuup)
GO(glNamedProgramLocalParameterI4iEXT, vFuuuiiii)
GO(glNamedProgramLocalParameterI4ivEXT, vFuuup)
GO(glNamedProgramLocalParameterI4uiEXT, vFuuuuuuu)
GO(glNamedProgramLocalParameterI4uivEXT, vFuuup)
GO(glNamedProgramLocalParameters4fvEXT, vFuuuip)
GO(glNamedProgramLocalParametersI4ivEXT, vFuuuip)
GO(glNamedProgramLocalParametersI4uivEXT, vFuuuip)
GO(glNamedProgramStringEXT, vFuuuip)
GO(glNamedRenderbufferStorageEXT, vFuuii)
GO(glNamedRenderbufferStorageMultisampleCoverageEXT, vFuiiuii)
GO(glNamedRenderbufferStorageMultisampleEXT, vFuiuii)
GO(glProgramUniform1dEXT, vFuid)
GO(glProgramUniform1dvEXT, vFuiip)
GO(glProgramUniform1fEXT, vFuif)
GO(glProgramUniform1fvEXT, vFuiip)
GO(glProgramUniform1iEXT, vFuii)
GO(glProgramUniform1ivEXT, vFuiip)
GO(glProgramUniform1uiEXT, vFuiu)
GO(glProgramUniform1uivEXT, vFuiip)
GO(glProgramUniform2dEXT, vFuidd)
GO(glProgramUniform2dvEXT, vFuiip)
GO(glProgramUniform2fEXT, vFuiff)
GO(glProgramUniform2fvEXT, vFuiip)
GO(glProgramUniform2iEXT, vFuiii)
GO(glProgramUniform2ivEXT, vFuiip)
GO(glProgramUniform2uiEXT, vFuiuu)
GO(glProgramUniform2uivEXT, vFuiip)
GO(glProgramUniform3dEXT, vFuiddd)
GO(glProgramUniform3dvEXT, vFuiip)
GO(glProgramUniform3fEXT, vFuifff)
GO(glProgramUniform3fvEXT, vFuiip)
GO(glProgramUniform3iEXT, vFuiiii)
GO(glProgramUniform3ivEXT, vFuiip)
GO(glProgramUniform3uiEXT, vFuiuuu)
GO(glProgramUniform3uivEXT, vFuiip)
GO(glProgramUniform4dEXT, vFuidddd)
GO(glProgramUniform4dvEXT, vFuiip)
GO(glProgramUniform4fEXT, vFuiffff)
GO(glProgramUniform4fvEXT, vFuiip)
GO(glProgramUniform4iEXT, vFuiiiii)
GO(glProgramUniform4ivEXT, vFuiip)
GO(glProgramUniform4uiEXT, vFuiuuuu)
GO(glProgramUniform4uivEXT, vFuiip)
GO(glProgramUniformMatrix2dvEXT, vFuiiCp)
GO(glProgramUniformMatrix2fvEXT, vFuiiCp)
GO(glProgramUniformMatrix2x3dvEXT, vFuiiCp)
GO(glProgramUniformMatrix2x3fvEXT, vFuiiCp)
GO(glProgramUniformMatrix2x4dvEXT, vFuiiCp)
GO(glProgramUniformMatrix2x4fvEXT, vFuiiCp)
GO(glProgramUniformMatrix3dvEXT, vFuiiCp)
GO(glProgramUniformMatrix3fvEXT, vFuiiCp)
GO(glProgramUniformMatrix3x2dvEXT, vFuiiCp)
GO(glProgramUniformMatrix3x2fvEXT, vFuiiCp)
GO(glProgramUniformMatrix3x4dvEXT, vFuiiCp)
GO(glProgramUniformMatrix3x4fvEXT, vFuiiCp)
GO(glProgramUniformMatrix4dvEXT, vFuiiCp)
GO(glProgramUniformMatrix4fvEXT, vFuiiCp)
GO(glProgramUniformMatrix4x2dvEXT, vFuiiCp)
GO(glProgramUniformMatrix4x2fvEXT, vFuiiCp)
GO(glProgramUniformMatrix4x3dvEXT, vFuiiCp)
GO(glProgramUniformMatrix4x3fvEXT, vFuiiCp)
GO(glPushClientAttribDefaultEXT, vFu)
GO(glTextureBufferEXT, vFuuuu)
GO(glTextureImage1DEXT, vFuuiiiiuup)
GO(glTextureImage2DEXT, vFuuiiiiiuup)
GO(glTextureImage3DEXT, vFuuiiiiiiuup)
GO(glTextureParameterIivEXT, vFuuup)
GO(glTextureParameterIuivEXT, vFuuup)
GO(glTextureParameterfEXT, vFuuuf)
GO(glTextureParameterfvEXT, vFuuup)
GO(glTextureParameteriEXT, vFuuui)
GO(glTextureParameterivEXT, vFuuup)
GO(glTextureRenderbufferEXT, vFuuu)
GO(glTextureSubImage1DEXT, vFuuiiiuup)
GO(glTextureSubImage2DEXT, vFuuiiiiiuup)
GO(glTextureSubImage3DEXT, vFuuiiiiiiiuup)
GO(glUnmapNamedBufferEXT, CFu)
GO(glVertexArrayColorOffsetEXT, vFuuiuil)
GO(glVertexArrayEdgeFlagOffsetEXT, vFuuil)
GO(glVertexArrayFogCoordOffsetEXT, vFuuuil)
GO(glVertexArrayIndexOffsetEXT, vFuuuil)
GO(glVertexArrayMultiTexCoordOffsetEXT, vFuuuiuil)
GO(glVertexArrayNormalOffsetEXT, vFuuuil)
GO(glVertexArraySecondaryColorOffsetEXT, vFuuiuil)
GO(glVertexArrayTexCoordOffsetEXT, vFuuiuil)
GO(glVertexArrayVertexAttribIOffsetEXT, vFuuuiuil)
GO(glVertexArrayVertexAttribOffsetEXT, vFuuuiuCil)
GO(glVertexArrayVertexOffsetEXT, vFuuiuil)
//EXT_draw_buffers2
GO(glColorMaskIndexedEXT, vFuCCCC)
GO(glDisableIndexedEXT, vFuu)
GO(glEnableIndexedEXT, vFuu)
GO(glGetBooleanIndexedvEXT, vFuup)
GO(glGetIntegerIndexedvEXT, vFuup)
GO(glIsEnabledIndexedEXT, CFuu)
//EXT_draw_instanced
GO(glDrawArraysInstancedEXT, vFuiii)
GO(glDrawElementsInstancedEXT, vFuiupi)
//EXT_draw_range_elements
GO(glDrawRangeElementsEXT, vFuuuiup)
//EXT_fog_coord
GO(glFogCoordPointerEXT, vFuip)
GO(glFogCoorddEXT, vFd)
GO(glFogCoorddvEXT, vFp)
GO(glFogCoordfEXT, vFf)
GO(glFogCoordfvEXT, vFp)
//EXT_framebuffer_blit
GO(glBlitFramebufferEXT, vFiiiiiiiiuu)
//EXT_framebuffer_object
GO(glBindFramebufferEXT, vFuu)
GO(glBindRenderbufferEXT, vFuu)
GO(glCheckFramebufferStatusEXT, uFu)
GO(glDeleteFramebuffersEXT, vFip)
GO(glDeleteRenderbuffersEXT, vFip)
GO(glFramebufferRenderbufferEXT, vFuuuu)
GO(glFramebufferTexture1DEXT, vFuuuui)
GO(glFramebufferTexture2DEXT, vFuuuui)
GO(glFramebufferTexture3DEXT, vFuuuuii)
GO(glGenFramebuffersEXT, vFip)
GO(glGenRenderbuffersEXT, vFip)
GO(glGenerateMipmapEXT, vFu)
GO(glGetFramebufferAttachmentParameterivEXT, vFuuup)
GO(glGetRenderbufferParameterivEXT, vFuup)
GO(glIsFramebufferEXT, CFu)
GO(glIsRenderbufferEXT, CFu)
GO(glRenderbufferStorageEXT, vFuuii)
//EXT_geometry_shader4
GO(glProgramParameteriEXT, vFuui)
//EXT_gpu_program_parameters
GO(glProgramEnvParameters4fvEXT, vFuuip)
GO(glProgramLocalParameters4fvEXT, vFuuip)
//EXT_gpu_shader4
GO(glBindFragDataLocationEXT, vFuup)
GO(glGetFragDataLocationEXT, iFup)
GO(glGetUniformuivEXT, vFuip)
GO(glUniform1uiEXT, vFiu)
GO(glUniform1uivEXT, vFiip)
GO(glUniform2uiEXT, vFiuu)
GO(glUniform2uivEXT, vFiip)
GO(glUniform3uiEXT, vFiuuu)
GO(glUniform3uivEXT, vFiip)
GO(glUniform4uiEXT, vFiuuuu)
GO(glUniform4uivEXT, vFiip)
//EXT_histogram
GO(glGetHistogramEXT, vFuCuup)
GO(glGetHistogramParameterfvEXT, vFuup)
GO(glGetHistogramParameterivEXT, vFuup)
GO(glGetMinmaxEXT, vFuCuup)
GO(glGetMinmaxParameterfvEXT, vFuup)
GO(glGetMinmaxParameterivEXT, vFuup)
GO(glHistogramEXT, vFuiuC)
GO(glMinmaxEXT, vFuuC)
GO(glResetHistogramEXT, vFu)
GO(glResetMinmaxEXT, vFu)
//EXT_index_func
GO(glIndexFuncEXT, vFuf)
//EXT_index_material
GO(glIndexMaterialEXT, vFuu)
//EXT_light_texture
GO(glApplyTextureEXT, vFu)
GO(glTextureLightEXT, vFu)
GO(glTextureMaterialEXT, vFuu)
//EXT_multi_draw_arrays
GO(glMultiDrawArraysEXT, vFuppi)
GOM(glMultiDrawElementsEXT, vFEupupi)
//EXT_multisample
GO(glSampleMaskEXT, vFfC)
GO(glSamplePatternEXT, vFu)
//EXT_paletted_texture
GO(glColorTableEXT, vFuuiuup)
GO(glGetColorTableEXT, vFuuup)
GO(glGetColorTableParameterfvEXT, vFuup)
GO(glGetColorTableParameterivEXT, vFuup)
//EXT_pixel_transform
GO(glGetPixelTransformParameterfvEXT, vFuup)
GO(glGetPixelTransformParameterivEXT, vFuup)
GO(glPixelTransformParameterfEXT, vFuuf)
GO(glPixelTransformParameterfvEXT, vFuup)
GO(glPixelTransformParameteriEXT, vFuui)
GO(glPixelTransformParameterivEXT, vFuup)
//EXT_point_parameters
GO(glPointParameterfEXT, vFuf)
GO(glPointParameterfvEXT, vFup)
//EXT_polygon_offset
GO(glPolygonOffsetEXT, vFff)
//EXT_provoking_vertex
GO(glProvokingVertexEXT, vFu)
//EXT_secondary_color
GO(glSecondaryColor3bEXT, vFccc)
GO(glSecondaryColor3bvEXT, vFp)
GO(glSecondaryColor3dEXT, vFddd)
GO(glSecondaryColor3dvEXT, vFp)
GO(glSecondaryColor3fEXT, vFfff)
GO(glSecondaryColor3fvEXT, vFp)
GO(glSecondaryColor3iEXT, vFiii)
GO(glSecondaryColor3ivEXT, vFp)
GO(glSecondaryColor3sEXT, vFwww)
GO(glSecondaryColor3svEXT, vFp)
GO(glSecondaryColor3ubEXT, vFCCC)
GO(glSecondaryColor3ubvEXT, vFp)
GO(glSecondaryColor3uiEXT, vFuuu)
GO(glSecondaryColor3uivEXT, vFp)
GO(glSecondaryColor3usEXT, vFWWW)
GO(glSecondaryColor3usvEXT, vFp)
GO(glSecondaryColorPointerEXT, vFiuip)
//EXT_separate_shader_objects
GO(glActiveProgramEXT, vFu)
GO(glCreateShaderProgramEXT, uFup)
GO(glUseShaderProgramEXT, vFuu)
//EXT_shader_image_load_store
GO(glBindImageTextureEXT, vFuuiCiui)
GO(glMemoryBarrierEXT, vFu)
//EXT_stencil_clear_tag
GO(glStencilClearTagEXT, vFiu)
//EXT_stencil_two_side
GO(glActiveStencilFaceEXT, vFu)
//EXT_subtexture
GO(glTexSubImage1DEXT, vFuiiiuup)
GO(glTexSubImage2DEXT, vFuiiiiiuup)
//EXT_texture3D
GO(glTexImage3DEXT, vFuiuiiiiuup)
GO(glTexSubImage3DEXT, vFuiiiiiiiuup)
//EXT_texture_buffer_object
GO(glTexBufferEXT, vFuuu)
//EXT_texture_integer
GO(glClearColorIiEXT, vFiiii)
GO(glClearColorIuiEXT, vFuuuu)
GO(glGetTexParameterIivEXT, vFuup)
GO(glGetTexParameterIuivEXT, vFuup)
GO(glTexParameterIivEXT, vFuup)
GO(glTexParameterIuivEXT, vFuup)
//EXT_texture_object
GO(glAreTexturesResidentEXT, CFipp)
GO(glBindTextureEXT, vFuu)
GO(glDeleteTexturesEXT, vFip)
GO(glGenTexturesEXT, vFip)
GO(glIsTextureEXT, CFu)
GO(glPrioritizeTexturesEXT, vFipp)
//EXT_texture_perturb_normal
GO(glTextureNormalEXT, vFu)
//EXT_transform_feedback
GO(glBeginTransformFeedbackEXT, vFu)
GO(glBindBufferBaseEXT, vFuuu)
GO(glBindBufferOffsetEXT, vFuuul)
GO(glBindBufferRangeEXT, vFuuull)
GO(glEndTransformFeedbackEXT, vFv)
GO(glGetTransformFeedbackVaryingEXT, vFuuipppp)
GOM(glTransformFeedbackVaryingsEXT, vFEuipu)
//EXT_vertex_array
GO(glArrayElementEXT, vFi)
GO(glColorPointerEXT, vFiuiip)
GO(glDrawArraysEXT, vFuii)
GO(glEdgeFlagPointerEXT, vFiip)
GO(glGetPointervEXT, vFuBp_)
GO(glIndexPointerEXT, vFuiip)
GO(glNormalPointerEXT, vFuiip)
GO(glTexCoordPointerEXT, vFiuiip)
GO(glVertexPointerEXT, vFiuiip)
//EXT_vertex_attrib_64bit
GO(glGetVertexAttribLdvEXT, vFuup)
GO(glVertexArrayVertexAttribLOffsetEXT, vFuuuiuil)
GO(glVertexAttribL1dEXT, vFud)
GO(glVertexAttribL1dvEXT, vFup)
GO(glVertexAttribL2dEXT, vFudd)
GO(glVertexAttribL2dvEXT, vFup)
GO(glVertexAttribL3dEXT, vFuddd)
GO(glVertexAttribL3dvEXT, vFup)
GO(glVertexAttribL4dEXT, vFudddd)
GO(glVertexAttribL4dvEXT, vFup)
GO(glVertexAttribLPointerEXT, vFuiuip)
//EXT_vertex_shader
GO(glBeginVertexShaderEXT, vFv)
GO(glBindLightParameterEXT, uFuu)
GO(glBindMaterialParameterEXT, uFuu)
GO(glBindParameterEXT, uFu)
GO(glBindTexGenParameterEXT, uFuuu)
GO(glBindTextureUnitParameterEXT, uFuu)
GO(glBindVertexShaderEXT, vFu)
GO(glDeleteVertexShaderEXT, vFu)
GO(glDisableVariantClientStateEXT, vFu)
GO(glEnableVariantClientStateEXT, vFu)
GO(glEndVertexShaderEXT, vFv)
GO(glExtractComponentEXT, vFuuu)
GO(glGenSymbolsEXT, uFuuuu)
GO(glGenVertexShadersEXT, uFu)
GO(glGetInvariantBooleanvEXT, vFuup)
GO(glGetInvariantFloatvEXT, vFuup)
GO(glGetInvariantIntegervEXT, vFuup)
GO(glGetLocalConstantBooleanvEXT, vFuup)
GO(glGetLocalConstantFloatvEXT, vFuup)
GO(glGetLocalConstantIntegervEXT, vFuup)
GO(glGetVariantBooleanvEXT, vFuup)
GO(glGetVariantFloatvEXT, vFuup)
GO(glGetVariantIntegervEXT, vFuup)
GO(glGetVariantPointervEXT, vFuuBp_)
GO(glInsertComponentEXT, vFuuu)
GO(glIsVariantEnabledEXT, CFuu)
GO(glSetInvariantEXT, vFuup)
GO(glSetLocalConstantEXT, vFuup)
GO(glShaderOp1EXT, vFuuu)
GO(glShaderOp2EXT, vFuuuu)
GO(glShaderOp3EXT, vFuuuuu)
GO(glSwizzleEXT, vFuuuuuu)
GO(glVariantPointerEXT, vFuuup)
GO(glVariantbvEXT, vFup)
GO(glVariantdvEXT, vFup)
GO(glVariantfvEXT, vFup)
GO(glVariantivEXT, vFup)
GO(glVariantsvEXT, vFup)
GO(glVariantubvEXT, vFup)
GO(glVariantuivEXT, vFup)
GO(glVariantusvEXT, vFup)
GO(glWriteMaskEXT, vFuuuuuu)
//EXT_vertex_weighting
GO(glVertexWeightPointerEXT, vFiuip)
GO(glVertexWeightfEXT, vFf)
GO(glVertexWeightfvEXT, vFp)
//EXT_x11_sync_object
GO(glImportSyncEXT, pFulu)
//GREMEDY_frame_terminator
GO(glFrameTerminatorGREMEDY, vFv)
//GREMEDY_string_marker
GO(glStringMarkerGREMEDY, vFip)
//HP_image_transform
GO(glGetImageTransformParameterfvHP, vFuup)
GO(glGetImageTransformParameterivHP, vFuup)
GO(glImageTransformParameterfHP, vFuuf)
GO(glImageTransformParameterfvHP, vFuup)
GO(glImageTransformParameteriHP, vFuui)
GO(glImageTransformParameterivHP, vFuup)
//IBM_multimode_draw_arrays
GO(glMultiModeDrawArraysIBM, vFpppii)
GOM(glMultiModeDrawElementsIBM, vFEppupui)
//IBM_static_data
GO(glFlushStaticDataIBM, vFu)
//IBM_vertex_array_lists
GO(glColorPointerListIBM, vFiuibp_i)
GO(glEdgeFlagPointerListIBM, vFibp_i)
GO(glFogCoordPointerListIBM, vFuibp_i)
GO(glIndexPointerListIBM, vFuibp_i)
GO(glNormalPointerListIBM, vFuibp_i)
GO(glSecondaryColorPointerListIBM, vFiuibp_i)
GO(glTexCoordPointerListIBM, vFiuibp_i)
GO(glVertexPointerListIBM, vFiuibp_i)
//INGR_blend_func_separate
GO(glBlendFuncSeparateINGR, vFuuuu)
//INTEL_map_texture
GO(glMapTexture2DINTEL, pFuiupp)
GO(glSyncTextureINTEL, vFu)
GO(glUnmapTexture2DINTEL, vFui)
//INTEL_parallel_arrays
//GO(glColorPointervINTEL, vFiubp_)
//GO(glNormalPointervINTEL, vFubp_)
//GO(glTexCoordPointervINTEL, vFiubp_)
//GO(glVertexPointervINTEL, vFiubp_)
//KHR_debug
GOM(glDebugMessageCallback, vFEpp)   // not ideal, because the my_ version will always exist, even if glDebugMessageCallback doesn't
GO(glDebugMessageControl, vFuuuipC)
GO(glDebugMessageInsert, vFuuuuip)
GO(glGetDebugMessageLog, uFuipppppp)
GO(glGetObjectLabel, vFuuipp)
GO(glGetObjectPtrLabel, vFpipp)
GO(glObjectLabel, vFuuip)
GO(glObjectPtrLabel, vFpip)
GO(glPopDebugGroup, vFv)
GO(glPushDebugGroup, vFuuip)
//MESA_resize_buffers
GO(glResizeBuffersMESA, vFv)
//MESA_window_pos
GO(glWindowPos2dMESA, vFdd)
GO(glWindowPos2dvMESA, vFp)
GO(glWindowPos2fMESA, vFff)
GO(glWindowPos2fvMESA, vFp)
GO(glWindowPos2iMESA, vFii)
GO(glWindowPos2ivMESA, vFp)
GO(glWindowPos2sMESA, vFww)
GO(glWindowPos2svMESA, vFp)
GO(glWindowPos3dMESA, vFddd)
GO(glWindowPos3dvMESA, vFp)
GO(glWindowPos3fMESA, vFfff)
GO(glWindowPos3fvMESA, vFp)
GO(glWindowPos3iMESA, vFiii)
GO(glWindowPos3ivMESA, vFp)
GO(glWindowPos3sMESA, vFwww)
GO(glWindowPos3svMESA, vFp)
GO(glWindowPos4dMESA, vFdddd)
GO(glWindowPos4dvMESA, vFp)
GO(glWindowPos4fMESA, vFffff)
GO(glWindowPos4fvMESA, vFp)
GO(glWindowPos4iMESA, vFiiii)
GO(glWindowPos4ivMESA, vFp)
GO(glWindowPos4sMESA, vFwwww)
GO(glWindowPos4svMESA, vFp)
//NVX_conditional_render
GO(glBeginConditionalRenderNVX, vFu)
GO(glEndConditionalRenderNVX, vFv)
//NV_bindless_texture
GO(glGetImageHandleNV, UFuiCiu)
GO(glGetTextureHandleNV, UFu)
GO(glGetTextureSamplerHandleNV, UFuu)
GO(glIsImageHandleResidentNV, CFU)
GO(glIsTextureHandleResidentNV, CFU)
GO(glMakeImageHandleNonResidentNV, vFU)
GO(glMakeImageHandleResidentNV, vFUu)
GO(glMakeTextureHandleNonResidentNV, vFU)
GO(glMakeTextureHandleResidentNV, vFU)
GO(glProgramUniformHandleui64NV, vFuiU)
GO(glProgramUniformHandleui64vNV, vFuiip)
GO(glUniformHandleui64NV, vFiU)
GO(glUniformHandleui64vNV, vFiip)
//NV_conditional_render
GO(glBeginConditionalRenderNV, vFuu)
GO(glEndConditionalRenderNV, vFv)
//NV_copy_image
GO(glCopyImageSubDataNV, vFuuiiiiuuiiiiiii)
//NV_depth_buffer_float
GO(glClearDepthdNV, vFd)
GO(glDepthBoundsdNV, vFdd)
GO(glDepthRangedNV, vFdd)
//NV_draw_texture
GO(glDrawTextureNV, vFuufffffffff)
//NV_evaluators
GO(glEvalMapsNV, vFuu)
GO(glGetMapAttribParameterfvNV, vFuuup)
GO(glGetMapAttribParameterivNV, vFuuup)
GO(glGetMapControlPointsNV, vFuuuiiCp)
GO(glGetMapParameterfvNV, vFuup)
GO(glGetMapParameterivNV, vFuup)
GO(glMapControlPointsNV, vFuuuiiiiCp)
GO(glMapParameterfvNV, vFuup)
GO(glMapParameterivNV, vFuup)
//NV_explicit_multisample
GO(glGetMultisamplefvNV, vFuup)
GO(glSampleMaskIndexedNV, vFuu)
GO(glTexRenderbufferNV, vFuu)
//NV_fence
GO(glDeleteFencesNV, vFip)
GO(glFinishFenceNV, vFu)
GO(glGenFencesNV, vFip)
GO(glGetFenceivNV, vFuup)
GO(glIsFenceNV, CFu)
GO(glSetFenceNV, vFuu)
GO(glTestFenceNV, CFu)
//NV_fragment_program
GO(glGetProgramNamedParameterdvNV, vFuipp)
GO(glGetProgramNamedParameterfvNV, vFuipp)
GO(glProgramNamedParameter4dNV, vFuipdddd)
GO(glProgramNamedParameter4dvNV, vFuipp)
GO(glProgramNamedParameter4fNV, vFuipffff)
GO(glProgramNamedParameter4fvNV, vFuipp)
//NV_framebuffer_multisample_coverage
GO(glRenderbufferStorageMultisampleCoverageNV, vFuiiuii)
//NV_geometry_program4
GO(glFramebufferTextureEXT, vFuuui)
GO(glFramebufferTextureFaceEXT, vFuuuiu)
GO(glFramebufferTextureLayerEXT, vFuuuii)
GO(glProgramVertexLimitNV, vFui)
//NV_gpu_program4
GO(glGetProgramEnvParameterIivNV, vFuup)
GO(glGetProgramEnvParameterIuivNV, vFuup)
GO(glGetProgramLocalParameterIivNV, vFuup)
GO(glGetProgramLocalParameterIuivNV, vFuup)
GO(glProgramEnvParameterI4iNV, vFuuiiii)
GO(glProgramEnvParameterI4ivNV, vFuup)
GO(glProgramEnvParameterI4uiNV, vFuuuuuu)
GO(glProgramEnvParameterI4uivNV, vFuup)
GO(glProgramEnvParametersI4ivNV, vFuuip)
GO(glProgramEnvParametersI4uivNV, vFuuip)
GO(glProgramLocalParameterI4iNV, vFuuiiii)
GO(glProgramLocalParameterI4ivNV, vFuup)
GO(glProgramLocalParameterI4uiNV, vFuuuuuu)
GO(glProgramLocalParameterI4uivNV, vFuup)
GO(glProgramLocalParametersI4ivNV, vFuuip)
GO(glProgramLocalParametersI4uivNV, vFuuip)
//NV_gpu_program5
GO(glGetProgramSubroutineParameteruivNV, vFuup)
GO(glProgramSubroutineParametersuivNV, vFuip)
//NV_gpu_shader5
GO(glGetUniformi64vNV, vFuip)
GO(glProgramUniform1i64NV, vFuiI)
GO(glProgramUniform1i64vNV, vFuiip)
GO(glProgramUniform1ui64NV, vFuiU)
GO(glProgramUniform1ui64vNV, vFuiip)
GO(glProgramUniform2i64NV, vFuiII)
GO(glProgramUniform2i64vNV, vFuiip)
GO(glProgramUniform2ui64NV, vFuiUU)
GO(glProgramUniform2ui64vNV, vFuiip)
GO(glProgramUniform3i64NV, vFuiIII)
GO(glProgramUniform3i64vNV, vFuiip)
GO(glProgramUniform3ui64NV, vFuiUUU)
GO(glProgramUniform3ui64vNV, vFuiip)
GO(glProgramUniform4i64NV, vFuiIIII)
GO(glProgramUniform4i64vNV, vFuiip)
GO(glProgramUniform4ui64NV, vFuiUUUU)
GO(glProgramUniform4ui64vNV, vFuiip)
GO(glUniform1i64NV, vFiI)
GO(glUniform1i64vNV, vFiip)
GO(glUniform1ui64NV, vFiU)
GO(glUniform1ui64vNV, vFiip)
GO(glUniform2i64NV, vFiII)
GO(glUniform2i64vNV, vFiip)
GO(glUniform2ui64NV, vFiUU)
GO(glUniform2ui64vNV, vFiip)
GO(glUniform3i64NV, vFiIII)
GO(glUniform3i64vNV, vFiip)
GO(glUniform3ui64NV, vFiUUU)
GO(glUniform3ui64vNV, vFiip)
GO(glUniform4i64NV, vFiIIII)
GO(glUniform4i64vNV, vFiip)
GO(glUniform4ui64NV, vFiUUUU)
GO(glUniform4ui64vNV, vFiip)
//NV_half_float
GO(glColor3hNV, vFWWW)
GO(glColor3hvNV, vFp)
GO(glColor4hNV, vFWWWW)
GO(glColor4hvNV, vFp)
GO(glFogCoordhNV, vFW)
GO(glFogCoordhvNV, vFp)
GO(glMultiTexCoord1hNV, vFuW)
GO(glMultiTexCoord1hvNV, vFup)
GO(glMultiTexCoord2hNV, vFuWW)
GO(glMultiTexCoord2hvNV, vFup)
GO(glMultiTexCoord3hNV, vFuWWW)
GO(glMultiTexCoord3hvNV, vFup)
GO(glMultiTexCoord4hNV, vFuWWWW)
GO(glMultiTexCoord4hvNV, vFup)
GO(glNormal3hNV, vFWWW)
GO(glNormal3hvNV, vFp)
GO(glSecondaryColor3hNV, vFWWW)
GO(glSecondaryColor3hvNV, vFp)
GO(glTexCoord1hNV, vFW)
GO(glTexCoord1hvNV, vFp)
GO(glTexCoord2hNV, vFWW)
GO(glTexCoord2hvNV, vFp)
GO(glTexCoord3hNV, vFWWW)
GO(glTexCoord3hvNV, vFp)
GO(glTexCoord4hNV, vFWWWW)
GO(glTexCoord4hvNV, vFp)
GO(glVertex2hNV, vFWW)
GO(glVertex2hvNV, vFp)
GO(glVertex3hNV, vFWWW)
GO(glVertex3hvNV, vFp)
GO(glVertex4hNV, vFWWWW)
GO(glVertex4hvNV, vFp)
GO(glVertexAttrib1hNV, vFuW)
GO(glVertexAttrib1hvNV, vFup)
GO(glVertexAttrib2hNV, vFuWW)
GO(glVertexAttrib2hvNV, vFup)
GO(glVertexAttrib3hNV, vFuWWW)
GO(glVertexAttrib3hvNV, vFup)
GO(glVertexAttrib4hNV, vFuWWWW)
GO(glVertexAttrib4hvNV, vFup)
GO(glVertexAttribs1hvNV, vFuip)
GO(glVertexAttribs2hvNV, vFuip)
GO(glVertexAttribs3hvNV, vFuip)
GO(glVertexAttribs4hvNV, vFuip)
GO(glVertexWeighthNV, vFW)
GO(glVertexWeighthvNV, vFp)
//NV_occlusion_query
GO(glBeginOcclusionQueryNV, vFu)
GO(glDeleteOcclusionQueriesNV, vFip)
GO(glEndOcclusionQueryNV, vFv)
GO(glGenOcclusionQueriesNV, vFip)
GO(glGetOcclusionQueryivNV, vFuup)
GO(glGetOcclusionQueryuivNV, vFuup)
GO(glIsOcclusionQueryNV, CFu)
//NV_parameter_buffer_object
GO(glProgramBufferParametersIivNV, vFuuuip)
GO(glProgramBufferParametersIuivNV, vFuuuip)
GO(glProgramBufferParametersfvNV, vFuuuip)
//NV_pixel_data_range
GO(glFlushPixelDataRangeNV, vFu)
GO(glPixelDataRangeNV, vFuip)
//NV_point_sprite
GO(glPointParameteriNV, vFui)
GO(glPointParameterivNV, vFup)
//NV_present_video
GO(glGetVideoi64vNV, vFuup)
GO(glGetVideoivNV, vFuup)
GO(glGetVideoui64vNV, vFuup)
GO(glGetVideouivNV, vFuup)
GO(glPresentFrameDualFillNV, vFuUuuuuuuuuuuu)
GO(glPresentFrameKeyedNV, vFuUuuuuuuuuu)
//NV_primitive_restart
GO(glPrimitiveRestartIndexNV, vFu)
GO(glPrimitiveRestartNV, vFv)
//NV_register_combiners
GO(glCombinerInputNV, vFuuuuuu)
GO(glCombinerOutputNV, vFuuuuuuuCCC)
GO(glCombinerParameterfNV, vFuf)
GO(glCombinerParameterfvNV, vFup)
GO(glCombinerParameteriNV, vFui)
GO(glCombinerParameterivNV, vFup)
GO(glFinalCombinerInputNV, vFuuuu)
GO(glGetCombinerInputParameterfvNV, vFuuuup)
GO(glGetCombinerInputParameterivNV, vFuuuup)
GO(glGetCombinerOutputParameterfvNV, vFuuup)
GO(glGetCombinerOutputParameterivNV, vFuuup)
GO(glGetFinalCombinerInputParameterfvNV, vFuup)
GO(glGetFinalCombinerInputParameterivNV, vFuup)
//NV_register_combiners2
GO(glCombinerStageParameterfvNV, vFuup)
GO(glGetCombinerStageParameterfvNV, vFuup)
//NV_shader_buffer_load
GO(glGetBufferParameterui64vNV, vFuup)
GO(glGetIntegerui64vNV, vFup)
GO(glGetNamedBufferParameterui64vNV, vFuup)
GO(glGetUniformui64vNV, vFuip)
GO(glIsBufferResidentNV, CFu)
GO(glIsNamedBufferResidentNV, CFu)
GO(glMakeBufferNonResidentNV, vFu)
GO(glMakeBufferResidentNV, vFuu)
GO(glMakeNamedBufferNonResidentNV, vFu)
GO(glMakeNamedBufferResidentNV, vFuu)
GO(glProgramUniformui64NV, vFuiU)
GO(glProgramUniformui64vNV, vFuiip)
GO(glUniformui64NV, vFiU)
GO(glUniformui64vNV, vFiip)
//NV_texture_barrier
GO(glTextureBarrierNV, vFv)
//NV_texture_multisample
GO(glTexImage2DMultisampleCoverageNV, vFuiiiiiC)
GO(glTexImage3DMultisampleCoverageNV, vFuiiiiiiC)
GO(glTextureImage2DMultisampleCoverageNV, vFuuiiiiiC)
GO(glTextureImage2DMultisampleNV, vFuuiiiiC)
GO(glTextureImage3DMultisampleCoverageNV, vFuuiiiiiiC)
GO(glTextureImage3DMultisampleNV, vFuuiiiiiC)
//NV_transform_feedback
GO(glActiveVaryingNV, vFup)
GO(glBeginTransformFeedbackNV, vFu)
GO(glBindBufferBaseNV, vFuuu)
GO(glBindBufferOffsetNV, vFuuul)
GO(glBindBufferRangeNV, vFuuull)
GO(glEndTransformFeedbackNV, vFv)
GO(glGetActiveVaryingNV, vFuuipppp)
GO(glGetTransformFeedbackVaryingNV, vFuup)
GO(glGetVaryingLocationNV, iFup)
GO(glTransformFeedbackAttribsNV, vFipu)
GO(glTransformFeedbackStreamAttribsNV, vFipipu)
GO(glTransformFeedbackVaryingsNV, vFuipu)
//NV_transform_feedback2
GO(glBindTransformFeedbackNV, vFuu)
GO(glDeleteTransformFeedbacksNV, vFip)
GO(glDrawTransformFeedbackNV, vFuu)
GO(glGenTransformFeedbacksNV, vFip)
GO(glIsTransformFeedbackNV, CFu)
GO(glPauseTransformFeedbackNV, vFv)
GO(glResumeTransformFeedbackNV, vFv)
//NV_vdpau_interop
GO(glVDPAUFiniNV, vFv)
GO(glVDPAUGetSurfaceivNV, vFluipp)
GO(glVDPAUInitNV, vFpp)
GO(glVDPAUIsSurfaceNV, CFl)
GOM(glVDPAUMapSurfacesNV, vFEip)
GO(glVDPAURegisterOutputSurfaceNV, lFpuip)
GO(glVDPAURegisterVideoSurfaceNV, lFpuip)
GO(glVDPAUSurfaceAccessNV, vFlu)
GOM(glVDPAUUnmapSurfacesNV, vFEip)
GO(glVDPAUUnregisterSurfaceNV, vFl)
//NV_vertex_array_range
GO(glFlushVertexArrayRangeNV, vFv)
GO(glVertexArrayRangeNV, vFip)
//NV_vertex_attrib_integer_64bit
GO(glGetVertexAttribLi64vNV, vFuup)
GO(glGetVertexAttribLui64vNV, vFuup)
GO(glVertexAttribL1i64NV, vFuI)
GO(glVertexAttribL1i64vNV, vFup)
GO(glVertexAttribL1ui64NV, vFuU)
GO(glVertexAttribL1ui64vNV, vFup)
GO(glVertexAttribL2i64NV, vFuII)
GO(glVertexAttribL2i64vNV, vFup)
GO(glVertexAttribL2ui64NV, vFuUU)
GO(glVertexAttribL2ui64vNV, vFup)
GO(glVertexAttribL3i64NV, vFuIII)
GO(glVertexAttribL3i64vNV, vFup)
GO(glVertexAttribL3ui64NV, vFuUUU)
GO(glVertexAttribL3ui64vNV, vFup)
GO(glVertexAttribL4i64NV, vFuIIII)
GO(glVertexAttribL4i64vNV, vFup)
GO(glVertexAttribL4ui64NV, vFuUUUU)
GO(glVertexAttribL4ui64vNV, vFup)
GO(glVertexAttribLFormatNV, vFuiui)
//NV_vertex_buffer_unified_memory
GO(glBufferAddressRangeNV, vFuuUl)
GO(glColorFormatNV, vFiui)
GO(glEdgeFlagFormatNV, vFi)
GO(glFogCoordFormatNV, vFui)
GO(glGetIntegerui64i_vNV, vFuup)
GO(glIndexFormatNV, vFui)
GO(glNormalFormatNV, vFui)
GO(glSecondaryColorFormatNV, vFiui)
GO(glTexCoordFormatNV, vFiui)
GO(glVertexAttribFormatNV, vFuiuCi)
GO(glVertexAttribIFormatNV, vFuiui)
GO(glVertexFormatNV, vFiui)
//NV_vertex_program
GO(glAreProgramsResidentNV, CFipp)
GO(glBindProgramNV, vFuu)
GO(glDeleteProgramsNV, vFip)
GO(glExecuteProgramNV, vFuup)
GO(glGenProgramsNV, vFip)
GO(glGetProgramParameterdvNV, vFuuup)
GO(glGetProgramParameterfvNV, vFuuup)
GO(glGetProgramStringNV, vFuup)
GO(glGetProgramivNV, vFuup)
GO(glGetTrackMatrixivNV, vFuuup)
GO(glGetVertexAttribPointervNV, vFuuBp_)
GO(glGetVertexAttribdvNV, vFuup)
GO(glGetVertexAttribfvNV, vFuup)
GO(glGetVertexAttribivNV, vFuup)
GO(glIsProgramNV, CFu)
GO(glLoadProgramNV, vFuuip)
GO(glProgramParameter4dNV, vFuudddd)
GO(glProgramParameter4dvNV, vFuup)
GO(glProgramParameter4fNV, vFuuffff)
GO(glProgramParameter4fvNV, vFuup)
GO(glProgramParameters4dvNV, vFuuip)
GO(glProgramParameters4fvNV, vFuuip)
GO(glRequestResidentProgramsNV, vFip)
GO(glTrackMatrixNV, vFuuuu)
GO(glVertexAttrib1dNV, vFud)
GO(glVertexAttrib1dvNV, vFup)
GO(glVertexAttrib1fNV, vFuf)
GO(glVertexAttrib1fvNV, vFup)
GO(glVertexAttrib1sNV, vFuw)
GO(glVertexAttrib1svNV, vFup)
GO(glVertexAttrib2dNV, vFudd)
GO(glVertexAttrib2dvNV, vFup)
GO(glVertexAttrib2fNV, vFuff)
GO(glVertexAttrib2fvNV, vFup)
GO(glVertexAttrib2sNV, vFuww)
GO(glVertexAttrib2svNV, vFup)
GO(glVertexAttrib3dNV, vFuddd)
GO(glVertexAttrib3dvNV, vFup)
GO(glVertexAttrib3fNV, vFufff)
GO(glVertexAttrib3fvNV, vFup)
GO(glVertexAttrib3sNV, vFuwww)
GO(glVertexAttrib3svNV, vFup)
GO(glVertexAttrib4dNV, vFudddd)
GO(glVertexAttrib4dvNV, vFup)
GO(glVertexAttrib4fNV, vFuffff)
GO(glVertexAttrib4fvNV, vFup)
GO(glVertexAttrib4sNV, vFuwwww)
GO(glVertexAttrib4svNV, vFup)
GO(glVertexAttrib4ubNV, vFuCCCC)
GO(glVertexAttrib4ubvNV, vFup)
GO(glVertexAttribPointerNV, vFuiuip)
GO(glVertexAttribs1dvNV, vFuip)
GO(glVertexAttribs1fvNV, vFuip)
GO(glVertexAttribs1svNV, vFuip)
GO(glVertexAttribs2dvNV, vFuip)
GO(glVertexAttribs2fvNV, vFuip)
GO(glVertexAttribs2svNV, vFuip)
GO(glVertexAttribs3dvNV, vFuip)
GO(glVertexAttribs3fvNV, vFuip)
GO(glVertexAttribs3svNV, vFuip)
GO(glVertexAttribs4dvNV, vFuip)
GO(glVertexAttribs4fvNV, vFuip)
GO(glVertexAttribs4svNV, vFuip)
GO(glVertexAttribs4ubvNV, vFuip)
//NV_vertex_program4
GO(glGetVertexAttribIivEXT, vFuup)
GO(glGetVertexAttribIuivEXT, vFuup)
GO(glVertexAttribI1iEXT, vFui)
GO(glVertexAttribI1ivEXT, vFup)
GO(glVertexAttribI1uiEXT, vFuu)
GO(glVertexAttribI1uivEXT, vFup)
GO(glVertexAttribI2iEXT, vFuii)
GO(glVertexAttribI2ivEXT, vFup)
GO(glVertexAttribI2uiEXT, vFuuu)
GO(glVertexAttribI2uivEXT, vFup)
GO(glVertexAttribI3iEXT, vFuiii)
GO(glVertexAttribI3ivEXT, vFup)
GO(glVertexAttribI3uiEXT, vFuuuu)
GO(glVertexAttribI3uivEXT, vFup)
GO(glVertexAttribI4bvEXT, vFup)
GO(glVertexAttribI4iEXT, vFuiiii)
GO(glVertexAttribI4ivEXT, vFup)
GO(glVertexAttribI4svEXT, vFup)
GO(glVertexAttribI4ubvEXT, vFup)
GO(glVertexAttribI4uiEXT, vFuuuuu)
GO(glVertexAttribI4uivEXT, vFup)
GO(glVertexAttribI4usvEXT, vFup)
GO(glVertexAttribIPointerEXT, vFuiuip)
//NV_video_capture
GO(glBeginVideoCaptureNV, vFu)
GO(glBindVideoCaptureStreamBufferNV, vFuuul)
GO(glBindVideoCaptureStreamTextureNV, vFuuuuu)
GO(glEndVideoCaptureNV, vFu)
GO(glGetVideoCaptureStreamdvNV, vFuuup)
GO(glGetVideoCaptureStreamfvNV, vFuuup)
GO(glGetVideoCaptureStreamivNV, vFuuup)
GO(glGetVideoCaptureivNV, vFuup)
GO(glVideoCaptureNV, uFupp)
GO(glVideoCaptureStreamParameterdvNV, vFuuup)
GO(glVideoCaptureStreamParameterfvNV, vFuuup)
GO(glVideoCaptureStreamParameterivNV, vFuuup)
//OES_byte_coordinates
GO(glMultiTexCoord1bOES, vFuc)
GO(glMultiTexCoord1bvOES, vFup)
GO(glMultiTexCoord2bOES, vFucc)
GO(glMultiTexCoord2bvOES, vFup)
GO(glMultiTexCoord3bOES, vFuccc)
GO(glMultiTexCoord3bvOES, vFup)
GO(glMultiTexCoord4bOES, vFucccc)
GO(glMultiTexCoord4bvOES, vFup)
GO(glTexCoord1bOES, vFc)
GO(glTexCoord1bvOES, vFp)
GO(glTexCoord2bOES, vFcc)
GO(glTexCoord2bvOES, vFp)
GO(glTexCoord3bOES, vFccc)
GO(glTexCoord3bvOES, vFp)
GO(glTexCoord4bOES, vFcccc)
GO(glTexCoord4bvOES, vFp)
GO(glVertex2bOES, vFcc)
GO(glVertex2bvOES, vFp)
GO(glVertex3bOES, vFccc)
GO(glVertex3bvOES, vFp)
GO(glVertex4bOES, vFcccc)
GO(glVertex4bvOES, vFp)
//OES_fixed_point
GO(glAccumxOES, vFui)
GO(glAlphaFuncxOES, vFui)
GO(glBitmapxOES, vFiiiiiip)
GO(glBlendColorxOES, vFiiii)
GO(glClearAccumxOES, vFiiii)
GO(glClearColorxOES, vFiiii)
GO(glClearDepthxOES, vFi)
GO(glClipPlanexOES, vFup)
GO(glColor3xOES, vFiii)
GO(glColor3xvOES, vFp)
GO(glColor4xOES, vFiiii)
GO(glColor4xvOES, vFp)
GO(glConvolutionParameterxOES, vFuui)
GO(glConvolutionParameterxvOES, vFuup)
GO(glDepthRangexOES, vFii)
GO(glEvalCoord1xOES, vFi)
GO(glEvalCoord1xvOES, vFp)
GO(glEvalCoord2xOES, vFii)
GO(glEvalCoord2xvOES, vFp)
GO(glFeedbackBufferxOES, vFiup)
GO(glFogxOES, vFui)
GO(glFogxvOES, vFup)
GO(glFrustumxOES, vFiiiiii)
GO(glGetClipPlanexOES, vFup)
GO(glGetConvolutionParameterxvOES, vFuup)
GO(glGetFixedvOES, vFup)
GO(glGetHistogramParameterxvOES, vFuup)
GO(glGetLightxOES, vFuup)
GO(glGetMapxvOES, vFuup)
GO(glGetMaterialxOES, vFuui)
GO(glGetPixelMapxv, vFuip)
GO(glGetTexEnvxvOES, vFuup)
GO(glGetTexGenxvOES, vFuup)
GO(glGetTexLevelParameterxvOES, vFuiup)
GO(glGetTexParameterxvOES, vFuup)
GO(glIndexxOES, vFi)
GO(glIndexxvOES, vFp)
GO(glLightModelxOES, vFui)
GO(glLightModelxvOES, vFup)
GO(glLightxOES, vFuui)
GO(glLightxvOES, vFuup)
GO(glLineWidthxOES, vFi)
GO(glLoadMatrixxOES, vFp)
GO(glLoadTransposeMatrixxOES, vFp)
GO(glMap1xOES, vFuiiiii)
GO(glMap2xOES, vFuiiiiiiiii)
GO(glMapGrid1xOES, vFiii)
GO(glMapGrid2xOES, vFiiiii)
GO(glMaterialxOES, vFuui)
GO(glMaterialxvOES, vFuup)
GO(glMultMatrixxOES, vFp)
GO(glMultTransposeMatrixxOES, vFp)
GO(glMultiTexCoord1xOES, vFui)
GO(glMultiTexCoord1xvOES, vFup)
GO(glMultiTexCoord2xOES, vFuii)
GO(glMultiTexCoord2xvOES, vFup)
GO(glMultiTexCoord3xOES, vFuiii)
GO(glMultiTexCoord3xvOES, vFup)
GO(glMultiTexCoord4xOES, vFuiiii)
GO(glMultiTexCoord4xvOES, vFup)
GO(glNormal3xOES, vFiii)
GO(glNormal3xvOES, vFp)
GO(glOrthoxOES, vFiiiiii)
GO(glPassThroughxOES, vFi)
GO(glPixelMapx, vFuip)
GO(glPixelStorex, vFui)
GO(glPixelTransferxOES, vFui)
GO(glPixelZoomxOES, vFii)
GO(glPointParameterxvOES, vFup)
GO(glPointSizexOES, vFi)
GO(glPolygonOffsetxOES, vFii)
GO(glPrioritizeTexturesxOES, vFipp)
GO(glRasterPos2xOES, vFii)
GO(glRasterPos2xvOES, vFp)
GO(glRasterPos3xOES, vFiii)
GO(glRasterPos3xvOES, vFp)
GO(glRasterPos4xOES, vFiiii)
GO(glRasterPos4xvOES, vFp)
GO(glRectxOES, vFiiii)
GO(glRectxvOES, vFpp)
GO(glRotatexOES, vFiiii)
GO(glSampleCoverageOES, vFii)
GO(glScalexOES, vFiii)
GO(glTexCoord1xOES, vFi)
GO(glTexCoord1xvOES, vFp)
GO(glTexCoord2xOES, vFii)
GO(glTexCoord2xvOES, vFp)
GO(glTexCoord3xOES, vFiii)
GO(glTexCoord3xvOES, vFp)
GO(glTexCoord4xOES, vFiiii)
GO(glTexCoord4xvOES, vFp)
GO(glTexEnvxOES, vFuui)
GO(glTexEnvxvOES, vFuup)
GO(glTexGenxOES, vFuui)
GO(glTexGenxvOES, vFuup)
GO(glTexParameterxOES, vFuui)
GO(glTexParameterxvOES, vFuup)
GO(glTranslatexOES, vFiii)
GO(glVertex2xOES, vFi)
GO(glVertex2xvOES, vFp)
GO(glVertex3xOES, vFii)
GO(glVertex3xvOES, vFp)
GO(glVertex4xOES, vFiii)
GO(glVertex4xvOES, vFp)
//OES_query_matrix
GO(glQueryMatrixxOES, uFpp)
//OES_single_precision
GO(glClearDepthfOES, vFf)
GO(glClipPlanefOES, vFup)
GO(glDepthRangefOES, vFff)
GO(glFrustumfOES, vFffffff)
GO(glGetClipPlanefOES, vFup)
GO(glOrthofOES, vFffffff)
//PGI_misc_hints
GO(glHintPGI, vFui)
//SGIS_detail_texture
GO(glDetailTexFuncSGIS, vFuip)
GO(glGetDetailTexFuncSGIS, vFup)
//SGIS_fog_function
GO(glFogFuncSGIS, vFip)
GO(glGetFogFuncSGIS, vFp)
//SGIS_multisample
GO(glSampleMaskSGIS, vFfC)
GO(glSamplePatternSGIS, vFu)
//SGIS_pixel_texture
GO(glGetPixelTexGenParameterfvSGIS, vFup)
GO(glGetPixelTexGenParameterivSGIS, vFup)
GO(glPixelTexGenParameterfSGIS, vFuf)
GO(glPixelTexGenParameterfvSGIS, vFup)
GO(glPixelTexGenParameteriSGIS, vFui)
GO(glPixelTexGenParameterivSGIS, vFup)
//SGIS_point_parameters
GO(glPointParameterfSGIS, vFuf)
GO(glPointParameterfvSGIS, vFup)
//SGIS_sharpen_texture
GO(glGetSharpenTexFuncSGIS, vFup)
GO(glSharpenTexFuncSGIS, vFuip)
//SGIS_texture4D
GO(glTexImage4DSGIS, vFuiuiiiiiuup)
GO(glTexSubImage4DSGIS, vFuiiiiiiiiiuup)
//SGIS_texture_color_mask
GO(glTextureColorMaskSGIS, vFCCCC)
//SGIS_texture_filter4
GO(glGetTexFilterFuncSGIS, vFuup)
GO(glTexFilterFuncSGIS, vFuuip)
//SGIX_async
GO(glAsyncMarkerSGIX, vFu)
GO(glDeleteAsyncMarkersSGIX, vFui)
GO(glFinishAsyncSGIX, iFp)
GO(glGenAsyncMarkersSGIX, uFi)
GO(glIsAsyncMarkerSGIX, CFu)
GO(glPollAsyncSGIX, iFp)
//SGIX_flush_raster
GO(glFlushRasterSGIX, vFv)
//SGIX_fragment_lighting
GO(glFragmentColorMaterialSGIX, vFuu)
GO(glFragmentLightModelfSGIX, vFuf)
GO(glFragmentLightModelfvSGIX, vFup)
GO(glFragmentLightModeliSGIX, vFui)
GO(glFragmentLightModelivSGIX, vFup)
GO(glFragmentLightfSGIX, vFuuf)
GO(glFragmentLightfvSGIX, vFuup)
GO(glFragmentLightiSGIX, vFuui)
GO(glFragmentLightivSGIX, vFuup)
GO(glFragmentMaterialfSGIX, vFuuf)
GO(glFragmentMaterialfvSGIX, vFuup)
GO(glFragmentMaterialiSGIX, vFuui)
GO(glFragmentMaterialivSGIX, vFuup)
GO(glGetFragmentLightfvSGIX, vFuup)
GO(glGetFragmentLightivSGIX, vFuup)
GO(glGetFragmentMaterialfvSGIX, vFuup)
GO(glGetFragmentMaterialivSGIX, vFuup)
GO(glLightEnviSGIX, vFui)
//SGIX_framezoom
GO(glFrameZoomSGIX, vFi)
//SGIX_igloo_interface
GO(glIglooInterfaceSGIX, vFup)
//SGIX_instruments
GO(glGetInstrumentsSGIX, iFv)
GO(glInstrumentsBufferSGIX, vFip)
GO(glPollInstrumentsSGIX, iFp)
GO(glReadInstrumentsSGIX, vFi)
GO(glStartInstrumentsSGIX, vFv)
GO(glStopInstrumentsSGIX, vFi)
//SGIX_list_priority
GO(glGetListParameterfvSGIX, vFuup)
GO(glGetListParameterivSGIX, vFuup)
GO(glListParameterfSGIX, vFuuf)
GO(glListParameterfvSGIX, vFuup)
GO(glListParameteriSGIX, vFuui)
GO(glListParameterivSGIX, vFuup)
//SGIX_pixel_texture
GO(glPixelTexGenSGIX, vFu)
//SGIX_polynomial_ffd
GO(glDeformSGIX, vFu)
GO(glDeformationMap3dSGIX, vFuddiiddiiddiip)
GO(glDeformationMap3fSGIX, vFuffiiffiiffiip)
GO(glLoadIdentityDeformationMapSGIX, vFu)
//SGIX_reference_plane
GO(glReferencePlaneSGIX, vFp)
//SGIX_sprite
GO(glSpriteParameterfSGIX, vFuf)
GO(glSpriteParameterfvSGIX, vFup)
GO(glSpriteParameteriSGIX, vFui)
GO(glSpriteParameterivSGIX, vFup)
//SGIX_tag_sample_buffer
GO(glTagSampleBufferSGIX, vFv)
//SGI_color_table
GO(glColorTableParameterfvSGI, vFuup)
GO(glColorTableParameterivSGI, vFuup)
GO(glColorTableSGI, vFuuiuup)
GO(glCopyColorTableSGI, vFuuiii)
GO(glGetColorTableParameterfvSGI, vFuup)
GO(glGetColorTableParameterivSGI, vFuup)
GO(glGetColorTableSGI, vFuuup)
//SUNX_constant_data
GO(glFinishTextureSUNX, vFv)
//SUN_global_alpha
GO(glGlobalAlphaFactorbSUN, vFc)
GO(glGlobalAlphaFactordSUN, vFd)
GO(glGlobalAlphaFactorfSUN, vFf)
GO(glGlobalAlphaFactoriSUN, vFi)
GO(glGlobalAlphaFactorsSUN, vFw)
GO(glGlobalAlphaFactorubSUN, vFC)
GO(glGlobalAlphaFactoruiSUN, vFu)
GO(glGlobalAlphaFactorusSUN, vFW)
//SUN_mesh_array
GO(glDrawMeshArraysSUN, vFuiii)
//SUN_triangle_list
GO(glReplacementCodePointerSUN, vFuibp_)
GO(glReplacementCodeubSUN, vFC)
GO(glReplacementCodeubvSUN, vFp)
GO(glReplacementCodeuiSUN, vFu)
GO(glReplacementCodeuivSUN, vFp)
GO(glReplacementCodeusSUN, vFW)
GO(glReplacementCodeusvSUN, vFp)
//SUN_vertex
GO(glColor3fVertex3fSUN, vFffffff)
GO(glColor3fVertex3fvSUN, vFpp)
GO(glColor4fNormal3fVertex3fSUN, vFffffffffff)
GO(glColor4fNormal3fVertex3fvSUN, vFppp)
GO(glColor4ubVertex2fSUN, vFCCCCff)
GO(glColor4ubVertex2fvSUN, vFpp)
GO(glColor4ubVertex3fSUN, vFCCCCfff)
GO(glColor4ubVertex3fvSUN, vFpp)
GO(glNormal3fVertex3fSUN, vFffffff)
GO(glNormal3fVertex3fvSUN, vFpp)
GO(glReplacementCodeuiColor3fVertex3fSUN, vFuffffff)
GO(glReplacementCodeuiColor3fVertex3fvSUN, vFppp)
GO(glReplacementCodeuiColor4fNormal3fVertex3fSUN, vFuffffffffff)
GO(glReplacementCodeuiColor4fNormal3fVertex3fvSUN, vFpppp)
GO(glReplacementCodeuiColor4ubVertex3fSUN, vFuCCCCfff)
GO(glReplacementCodeuiColor4ubVertex3fvSUN, vFppp)
GO(glReplacementCodeuiNormal3fVertex3fSUN, vFuffffff)
GO(glReplacementCodeuiNormal3fVertex3fvSUN, vFppp)
GO(glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN, vFuffffffffffff)
GO(glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN, vFppppp)
GO(glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN, vFuffffffff)
GO(glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN, vFpppp)
GO(glReplacementCodeuiTexCoord2fVertex3fSUN, vFufffff)
GO(glReplacementCodeuiTexCoord2fVertex3fvSUN, vFppp)
GO(glReplacementCodeuiVertex3fSUN, vFufff)
GO(glReplacementCodeuiVertex3fvSUN, vFpp)
GO(glTexCoord2fColor3fVertex3fSUN, vFffffffff)
GO(glTexCoord2fColor3fVertex3fvSUN, vFppp)
GO(glTexCoord2fColor4fNormal3fVertex3fSUN, vFffffffffffff)
GO(glTexCoord2fColor4fNormal3fVertex3fvSUN, vFpppp)
GO(glTexCoord2fColor4ubVertex3fSUN, vFffCCCCfff)
GO(glTexCoord2fColor4ubVertex3fvSUN, vFppp)
GO(glTexCoord2fNormal3fVertex3fSUN, vFffffffff)
GO(glTexCoord2fNormal3fVertex3fvSUN, vFppp)
GO(glTexCoord2fVertex3fSUN, vFfffff)
GO(glTexCoord2fVertex3fvSUN, vFpp)
GO(glTexCoord4fColor4fNormal3fVertex4fSUN, vFfffffffffffffff)
GO(glTexCoord4fColor4fNormal3fVertex4fvSUN, vFpppp)
GO(glTexCoord4fVertex4fSUN, vFffffffff)
GO(glTexCoord4fVertex4fvSUN, vFpp)

//GL_ARB_polygon_offset_clamp
GO(glPolygonOffsetClamp, vFfff)

//GL_EXT_polygon_offset_clamp
GO(glPolygonOffsetClampEXT, vFfff)

//GL_EXT_multisampled_render_to_texture
GO(glRenderbufferStorageMultisampleEXT, vFuiuii)
GO(glFramebufferTexture2DMultisampleEXT, vFiiiuil)

//GL_KTX_buffer_region
GO(glBufferRegionEnabled, uFv)
GO(glNewBufferRegion, uFi)
GO(glDeleteBufferRegion, vFi)
GO(glReadBufferRegion, vFuiiii)
GO(glDrawBufferRegion, vFuiiiiii)

//GL_ARB_sparse_buffer
GO(glBufferPageCommitmentARB, vFullC)
GO(glNamedBufferPageCommitmentARB, vFullC)
GO(glNamedBufferPageCommitmentEXT, vFullC)

//GL_ARB_sparse_texture
GO(TexPageCommitmentARB, vFiiiiiiiii)

//glx
GO(glXBindHyperpipeSGIX, iFXi)
GO(glXBindTexImageEXT, vFXpip)
GO(glXBindSwapBarrierNV, iFXuu)
GO(glXBindSwapBarrierSGIX, vFii)
GO(glXBindVideoCaptureDeviceNV, iFXup)
GO(glXBindVideoDeviceNV, iFXuup)
GO(glXBindVideoImageNV, iFXppi)
//GO(glXChangeDrawableAttributes, vFp)
//GO(glXChangeDrawableAttributesSGIX, vFp)
GO(glXClientInfo, vFv)
GO(glXCopyContext, vFXppL)
GOM(glXChooseFBConfig, pFEXipp)
GOM(glXChooseFBConfigSGIX, pFEXipp)
GOM(glXCreateContext, pFEXppi)
GO(glXCreateContextAttribsARB, pFXppip)
GO(glXCreateContextWithConfigSGIX, pFXpipi)
GO(glXCreateGLXPbufferSGIX, pFXpuup)
//GOM(glXCreateGLXPixmap, LFEXbpLiiiLLLii_L)
GO(glXCreateGLXPixmapWithConfigSGIX, pFXpp)
//GO(glXCreateGLXVideoSourceSGIX, pFpippip)
GO(glXCreateNewContext, pFXpipi)
GO(glXCreatePbuffer, LFXpp)
GO(glXCreatePixmap, LFXpLp)
GO(glXCreateWindow, LFXpLp)
GOM(glXChooseVisual, pFEXip)
GO(glXCopyImageSubDataNV, vFXpuiiiiipuiiiiiiii)
GO(glXCopySubBufferMESA, vFXpiiii)
GO(glXDestroyContext, vFXp)
GO(glXDestroyGLXPbufferSGIX, vFXp)
GO(glXDestroyGLXPixmap, vFXL)
//GO(glXDestroyGLXVideoSourceSGIX, vFpp)
//GO(glXDestroyHyperpipeConfigSGIX, iFpi)
GO(glXDestroyPbuffer, vFXL)
GO(glXDestroyPixmap, vFXL)
GO(glXDestroyWindow, vFXL)
GO(glXEnumerateVideoCaptureDevicesNV, pFXip)
GO(glXEnumerateVideoDevicesNV, pFXip)
GO(glXFreeContextEXT, vFXp)
GO(glXGetClientString, pFXi)
//GOM(glXGetConfig, iFEXbpLiiiLLLii_ip)
GO(glXGetContextIDEXT, uFp)
GO(glXGetCurrentContext, pFv)
GO(glXGetCurrentDisplay, XFv)
GO(glXGetCurrentDrawable, LFv)
GO(glXGetCurrentReadDrawable, LFv)
//GO(glXGetDrawableAttributes, vFi)
//GO(glXGetDrawableAttributesSGIX, vFi)
GOM(glXGetFBConfigs,pFEXip)
GO(glXGetFBConfigAttrib, iFXpip)
GO(glXGetFBConfigAttribSGIX, iFXpip)
GOM(glXGetFBConfigFromVisualSGIX, pFEXp)
//GO(glXGetFBConfigsSGIX, pFpip)
GO(glXGetSelectedEvent, vFXLbL_)
GO(glXGetSelectedEventSGIX, vFXpp)
GO(glXGetVideoDeviceNV, iFXiip)
GO(glXGetVideoInfoNV, iFpippp)
GO(glXGetVideoSyncSGI, iFp)
//GO(glXGetVisualConfigs, pFpp)
GOM(glXGetVisualFromFBConfig, pFEXp)
GOM(glXGetVisualFromFBConfigSGIX, pFEXp)
//GO(glXHyperpipeAttribSGIX, iFpiiip)
//GO(glXHyperpipeConfigSGIX, iFpiipp)
GO(glXImportContextEXT, pFXu)
GO(glXIsDirect, iFXp)
GO(glXJoinSwapGroupNV, iFXpu)
//GO(glXJoinSwapGroupSGIX, vFpp)
GO(glXLockVideoCaptureDeviceNV, vFXp)
GO(glXMakeContextCurrent, iFXLLp)
GO(glXMakeCurrent, iFXLp)
GO(glXQueryContext, iFXpip)
GO(glXQueryContextInfoEXT, iFXpip)
GO(glXQueryDrawable, vFXLip)
GO(glXQueryExtension, iFXpp)
GO(glXQueryExtensionsString, pFXi)
GO(glXQueryFrameCountNV, iFXip)
GO(glXQueryGLXPbufferSGIX, vFXpip)
//GO(glXQueryHyperpipeAttribSGIX, iFpiiip)
//GO(glXQueryHyperpipeBestAttribSGIX, iFpiiipp)
//GO(glXQueryHyperpipeConfigSGIX, pFpip)
//GO(glXQueryHyperpipeNetworkSGIX, pFpp)
//GO(glXQueryMaxSwapBarriersSGIX, pFpp)
GO(glXQueryMaxSwapGroupsNV, iFXipp)
GO(glXQueryServerString, pFXii)
GO(glXQuerySwapGroupNV, iFXipp)
GO(glXQueryVersion, iFXpp)
GO(glXQueryVideoCaptureDeviceNV, iFXpip)
GO(glXReleaseTexImageEXT, vFXpi)
GO(glXReleaseVideoCaptureDeviceNV, vFXp)
GO(glXReleaseVideoDeviceNV, iFXip)
GO(glXReleaseVideoImageNV, iFXp)
GO(glXRender, vFv)
GO(glXRenderLarge, vFv)
GO(glXResetFrameCountNV, iFXi)
GO(glXSelectEvent, vFXLL)
GO(glXSelectEventSGIX, vFXpL)
GO(glXSendPbufferToVideoNV, iFXpipi)
GO(glXSwapBuffers, vFXL)
GO(glXUseXFont, vFLiii)
GO(glXVendorPrivate, vFv)
GO(glXVendorPrivateWithReply, vFv)
GO(glXWaitGL, vFv)
GO(glXWaitVideoSyncSGI, iFiip)
GO(glXWaitX, vFv)

GOM(glXGetProcAddress, pFEp)
GOM(glXGetProcAddressARB, pFEp)

//GLX_MESA_query_renderer
GO(glXQueryRendererIntegerMESA, iFXiiip)
GO(glXQueryCurrentRendererIntegerMESA, iFip)
GO(glXQueryRendererStringMESA, pFXiii)
GO(glXQueryCurrentRendererStringMESA, pFi)

//GLX_OML_sync_control
GO(glXGetSyncValuesOML, iFXpppp)
GO(glXGetMscRateOML, iFXppp)
GO(glXSwapBuffersMscOML, IFXpIII)
GO(glXWaitForMscOML, iFXpIIIppp)
GO(glXWaitForSbcOML, iFXpIppp)

//GLX_EXT_swap_control
GOM(glXSwapIntervalEXT, vFEXpi)
//GLX_EXT_swap_control_tear
//nothing

//GLX_MESA_swap_control
GOM(glXSwapIntervalMESA, iFEi)
GO(glXGetSwapIntervalMESA, iFv)

//GLX_SGI_swap_control
GO(glXSwapIntervalSGI, iFi)

//GLX_NV_vertex_array_range
GO(glXAllocateMemoryNV, pFifff)
GO(glXFreeMemoryNV, vFp)

//GLX_ARB_????
GO(glSpecializeShaderARB, vFupupp)

//GLX_AMD_gpu_association
GO(glXGetGPUIDsAMD, uFup)
GO(glXGetGPUInfoAMD, iFuiuup)
GO(glXGetContextGPUIDAMD, uFp)
GO(glXCreateAssociatedContextAMD, pFup)
GO(glXCreateAssociatedContextAttribsAMD, pFupp)
GO(glXDeleteAssociatedContextAMD, iFp)
GO(glXMakeAssociatedContextCurrentAMD, iFp)
GO(glXGetCurrentAssociatedContextAMD, pFv)
GO(glXBlitContextFramebufferAMD, vFpiiiiiiiiuu)

//GL_EXT_debug_label
GO(glGetObjectLabelEXT, vFuuipp)
GO(glLabelObjectEXT, vFuuip)

//GL_EXT_debug_marker
GO(glInsertEventMarkerEXT, vFip)
GO(glPushGroupMarkerEXT, vFip)
GO(glPopGroupMarkerEXT, vFv)

//GL_KHR_blend_equation_advanced
GO(glBlendBarrierKHR, vFv)

//Some various other extension
GO(glResolveMultisampleFramebufferAPPLE, vFv)
GO(glTexPageCommitmentARB, vFuiiiiiiiC)

//GL_ARB_sample_locations
GO(glFramebufferSampleLocationsfvARB, vFuuip)
GO(glNamedFramebufferSampleLocationsfvARB, vFuuip)
GO(glEvaluateDepthValuesARB, vFv)

//GL_ARB_parallel_shader_compile
GO(glMaxShaderCompilerThreadsARB, vFu)

//GL_ARB_indirect_parameters
GO(glMultiDrawArraysIndirectCountARB, vFuplii)
GO(glMultiDrawElementsIndirectCountARB, vFuuplii)

//GL_ARB_gpu_shader_int64
GO(glUniform1i64ARB, vFiI)
GO(glUniform2i64ARB, vFiII)
GO(glUniform3i64ARB, vFiIII)
GO(glUniform4i64ARB, vFiIIII)
GO(glUniform1i64vARB, vFiip)
GO(glUniform2i64vARB, vFiip)
GO(glUniform3i64vARB, vFiip)
GO(glUniform4i64vARB, vFiip)
GO(glUniform1ui64ARB, vFiU)
GO(glUniform2ui64ARB, vFiUU)
GO(glUniform3ui64ARB, vFiUUU)
GO(glUniform4ui64ARB, vFiUUUU)
GO(glUniform1ui64vARB, vFiip)
GO(glUniform2ui64vARB, vFiip)
GO(glUniform3ui64vARB, vFiip)
GO(glUniform4ui64vARB, vFiip)
GO(glGetUniformi64vARB, vFuip)
GO(glGetUniformui64vARB, vFuip)
GO(glGetnUniformi64vARB, vFuiip)
GO(glGetnUniformui64vARB, vFuiip)
GO(glProgramUniform1i64ARB, vFuiI)
GO(glProgramUniform2i64ARB, vFuiII)
GO(glProgramUniform3i64ARB, vFuiIII)
GO(glProgramUniform4i64ARB, vFuiIIII)
GO(glProgramUniform1i64vARB, vFuiip)
GO(glProgramUniform2i64vARB, vFuiip)
GO(glProgramUniform3i64vARB, vFuiip)
GO(glProgramUniform4i64vARB, vFuiip)
GO(glProgramUniform1ui64ARB, vFuiU)
GO(glProgramUniform2ui64ARB, vFuiUU)
GO(glProgramUniform3ui64ARB, vFuiUUU)
GO(glProgramUniform4ui64ARB, vFuiUUUU)
GO(glProgramUniform1ui64vARB, vFuiip)
GO(glProgramUniform2ui64vARB, vFuiip)
GO(glProgramUniform3ui64vARB, vFuiip)
GO(glProgramUniform4ui64vARB, vFuiip)

//GL_ARB_compute_variable_group_size
GO(glDispatchComputeGroupSizeARB, vFuuuuuu)

//GL_ARB_ES3_2_compatibility
GO(glPrimitiveBoundingBoxARB, vFffffffff)

//GL_ARB_bindless_texture
GO(glGetTextureHandleARB, UFu)
GO(glGetTextureSamplerHandleARB, UFuu)
GO(glMakeTextureHandleResidentARB, vFU)
GO(glMakeTextureHandleNonResidentARB, vFU)
GO(glGetImageHandleARB, UFuiCiu)
GO(glMakeImageHandleResidentARB, vFUu)
GO(glMakeImageHandleNonResidentARB, vFU)
GO(glUniformHandleui64ARB, vFiU)
GO(glUniformHandleui64vARB, vFiip)
GO(glProgramUniformHandleui64ARB, vFuiU)
GO(glProgramUniformHandleui64vARB, vFuiip)
GO(glIsTextureHandleResidentARB, CFU)
GO(glIsImageHandleResidentARB, CFU)
GO(glVertexAttribL1ui64ARB, vFuU)
GO(glVertexAttribL1ui64vARB, vFup)
GO(glGetVertexAttribLui64vARB, vFuup)

//GL_OES_EGL_image
GO(glEGLImageTargetTexture2DOES, vFup)
GO(glEGLImageTargetRenderbufferStorageOES, vFup)

//GL_MESA_program_debug
GOM(glProgramCallbackMESA, vFEipp)
GO(glGetProgramRegisterfvMESA, vFilpp)

//GL_????_ATI
GO(glBlendEquationSeparateATI, vFuu)

//GL_AMD_interleaved_elements
GO(glVertexAttribParameteriAMD, vFuui)

//GL_AMD_occlusion_query_event
GO(glQueryObjectParameteruiAMD, vFuuuu)

//GL_EXT_raster_multisample
GO(glRasterSamplesEXT, vFuC)

//GL_INTEL_performance_query
GO(glBeginPerfQueryINTEL, vFu)
GO(glCreatePerfQueryINTEL, vFup)
GO(glDeletePerfQueryINTEL, vFu)
GO(glEndPerfQueryINTEL, vFu)
GO(glGetFirstPerfQueryIdINTEL, vFp)
GO(glGetNextPerfQueryIdINTEL, vFup)
GO(glGetPerfCounterInfoINTEL, vFuuupupppppp)
GO(glGetPerfQueryDataINTEL, vFuuipp)
GO(glGetPerfQueryIdByNameINTEL, vFpp)
GO(glGetPerfQueryInfoINTEL, vFuuppppp)

//GL_NV_bindless_multi_draw_indirect
GO(glMultiDrawArraysIndirectBindlessNV, vFupiii)
GO(glMultiDrawElementsIndirectBindlessNV, vFuupiii)

//GL_NV_bindless_multi_draw_indirect_count
GO(glMultiDrawArraysIndirectBindlessCountNV, vFupiiii)
GO(glMultiDrawElementsIndirectBindlessCountNV, vFuupiiii)

//GL_NV_blend_equation_advanced
GO(glBlendParameteriNV, vFui)
GO(glBlendBarrierNV, vFv)

//GL_NV_command_list
GO(glCreateStatesNV, vFip)
GO(glDeleteStatesNV, vFip)
GO(glIsStateNV, CFu)
GO(glStateCaptureNV, vFuu)
GO(glGetCommandHeaderNV, uFuu)
GO(glGetStageIndexNV, WFu)
//GO(glDrawCommandsNV, vFuubl_pu)
GO(glDrawCommandsAddressNV, vFuppu)
//GO(glDrawCommandsStatesNV, vFubl_pppu)
GO(glDrawCommandsStatesAddressNV, vFppppu)
GO(glCreateCommandListsNV, vFip)
GO(glDeleteCommandListsNV, vFip)
GO(glIsCommandListNV, CFu)
//GO(glListDrawCommandsStatesClientNV, vFuubp_pppu)
GO(glCommandListSegmentsNV, vFuu)
GO(glCompileCommandListNV, vFu)
GO(glCallCommandListNV, vFu)

//GL_NV_conservative_raster
GO(glSubpixelPrecisionBiasNV, vFuu)

//GL_NV_fragment_coverage_to_color
GO(glFragmentCoverageColorNV, vFu)

//GL_NV_framebuffer_mixed_samples
GO(glCoverageModulationTableNV, vFip)
GO(glGetCoverageModulationTableNV, vFip)
GO(glCoverageModulationNV, vFu)

//GL_NV_internalformat_sample_query
GO(glGetInternalformatSampleivNV, vFuuiuip)

//GL_NV_path_rendering
GO(glGenPathsNV, uFi)
GO(glDeletePathsNV, vFui)
GO(glIsPathNV, CFu)
GO(glPathCommandsNV, vFuipiup)
GO(glPathCoordsNV, vFuiup)
GO(glPathSubCommandsNV, vFuiiipiup)
GO(glPathSubCoordsNV, vFuiiup)
GO(glPathStringNV, vFuuip)
GO(glPathGlyphsNV, vFuupuiupuuf)
GO(glPathGlyphRangeNV, vFuupuuiuuf)
GO(glWeightPathsNV, vFuipp)
GO(glCopyPathNV, vFuu)
GO(glInterpolatePathsNV, vFuuuf)
GO(glTransformPathNV, vFuuup)
GO(glPathParameterivNV, vFuup)
GO(glPathParameteriNV, vFuui)
GO(glPathParameterfvNV, vFuup)
GO(glPathParameterfNV, vFuuf)
GO(glPathDashArrayNV, vFuip)
GO(glPathStencilFuncNV, vFuiu)
GO(glPathStencilDepthOffsetNV, vFff)
GO(glStencilFillPathNV, vFuuu)
GO(glStencilStrokePathNV, vFuiu)
GO(glStencilFillPathInstancedNV, vFiupuuuup)
GO(glStencilStrokePathInstancedNV, vFiupuiuup)
GO(glPathCoverDepthFuncNV, vFu)
GO(glCoverFillPathNV, vFuu)
GO(glCoverStrokePathNV, vFuu)
GO(glCoverFillPathInstancedNV, vFiupuuup)
GO(glCoverStrokePathInstancedNV, vFiupuuup)
GO(glGetPathParameterivNV, vFuup)
GO(glGetPathParameterfvNV, vFuup)
GO(glGetPathCommandsNV, vFup)
GO(glGetPathCoordsNV, vFup)
GO(glGetPathDashArrayNV, vFup)
GO(glGetPathMetricsNV, vFuiupuip)
GO(glGetPathMetricRangeNV, vFuuiip)
GO(glGetPathSpacingNV, vFuiupuffup)
GO(glIsPointInFillPathNV, CFuuff)
GO(glIsPointInStrokePathNV, CFuff)
GO(glGetPathLengthNV, fFuii)
GO(glPointAlongPathNV, CFuiifpppp)
GO(glMatrixLoad3x2fNV, vFup)
GO(glMatrixLoad3x3fNV, vFup)
GO(glMatrixLoadTranspose3x3fNV, vFup)
GO(glMatrixMult3x2fNV, vFup)
GO(glMatrixMult3x3fNV, vFup)
GO(glMatrixMultTranspose3x3fNV, vFup)
GO(glStencilThenCoverFillPathNV, vFuuuu)
GO(glStencilThenCoverStrokePathNV, vFuiuu)
GO(glStencilThenCoverFillPathInstancedNV, vFiupuuuuup)
GO(glStencilThenCoverStrokePathInstancedNV, vFiupuiuuup)
GO(glPathGlyphIndexRangeNV, uFupuufp)
GO(glPathGlyphIndexArrayNV, uFuupuuiuf)
GO(glPathMemoryGlyphIndexArrayNV, uFuulpiuiuf)
GO(glProgramPathFragmentInputGenNV, vFuiuip)
GO(glGetProgramResourcefvNV, vFuuuipipp)
GO(glPathColorGenNV, vFuuup)
GO(glPathTexGenNV, vFuuip)
GO(glPathFogGenNV, vFu)
GO(glGetPathColorGenivNV, vFuup)
GO(glGetPathColorGenfvNV, vFuup)
GO(glGetPathTexGenivNV, vFuup)
GO(glGetPathTexGenfvNV, vFuup)


//GL_NV_sample_locations
GO(glFramebufferSampleLocationsfvNV, vFuuip)
GO(glNamedFramebufferSampleLocationsfvNV, vFuuip)
GO(glResolveDepthValuesNV, vFv)

//GL_KHR_robustness
GO(glGetGraphicsResetStatusKHR, iFv)
GO(glReadnPixelsKHR, vFiilliilp)
GO(glGetnUniformfvKHR, vFuilp)
GO(glGetnUniformivKHR, vFuilp)
GO(glGetnUniformuivKHR, vFuilp)

// GLES stuff
GO(glDiscardFramebuffer, vFilp)
GO(glDiscardFramebufferARB, vFilp)
GO(glDiscardFramebufferEXT, vFilp)
GO(glDiscardFramebufferOES, vFilp)
GO(glDiscardFramebufferANGLE, vFilp)
GO(glDiscardFramebufferNV, vFilp)
GO(glBlendBarrier, vFv)
GO(glBlendBarrierARB, vFv)
GO(glBlendBarrierEXT, vFv)
GO(glBlendBarrierOES, vFv)
GO(glBlendBarrierANGLE, vFv)
GO(glClearDepthfARB, vFf)
GO(glClipPlanefARB, vFup)
GO(glDepthRangefARB, vFff)
GO(glFrustumfARB, vFffffff)
GO(glGetClipPlanefARB, vFup)
GO(glOrthofARB, vFffffff)
GO(glClipPlanef, vFup)
GO(glFrustumf, vFffffff)
GO(glGetClipPlanef, vFup)
GO(glOrthof, vFffffff)
GO(glActiveShaderProgramEXT, vFuu)
GO(glBindProgramPipelineEXT, vFu)
GO(glCreateShaderProgramvEXT, uFilp)
GO(glDeleteProgramPipelinesEXT, vFilu)
GO(glGenProgramPipelinesEXT, vFlp)
GO(glGetProgramPipelineInfoLogEXT, vFulpp)
GO(glGetProgramPipelineivEXT, vFuip)
GO(glIsProgramPipelineEXT, iFu)
GO(glUseProgramStagesEXT, vFuuu)
GO(glValidateProgramPipelineEXT, vFu)
GO(glPrimitiveBoundingBox, vFffffffff)

// GL_EXT_window_rectangles
GO(glWindowRectanglesEXT, vFuip)

// GL_EXT_memory_object
GO(glGetUnsignedBytevEXT, vFup)
GO(glGetUnsignedBytei_vEXT, vFuup)
GO(glDeleteMemoryObjectsEXT, vFip)
GO(glIsMemoryObjectEXT, CFu)
GO(glCreateMemoryObjectsEXT, vFip)
GO(glMemoryObjectParameterivEXT, vFuup)
GO(glGetMemoryObjectParameterivEXT, vFuup)
GO(glTexStorageMem2DEXT, vFuiuiiuU)
GO(glTexStorageMem2DMultisampleEXT, vFuiuiiCuU)
GO(glTexStorageMem3DEXT, vFuiuiiiuU)
GO(glTexStorageMem3DMultisampleEXT, vFuiuiiiCuU)
GO(glBufferStorageMemEXT, vFuluU)
GO(glTextureStorageMem2DEXT, vFuiuiiuU)
GO(glTextureStorageMem2DMultisampleEXT, vFuiuiiCuU)
GO(glTextureStorageMem3DEXT, vFuiuiiiuU)
GO(glTextureStorageMem3DMultisampleEXT, vFuiuiiiCuU)
GO(glNamedBufferStorageMemEXT, vFuluU)
GO(glTexStorageMem1DEXT, vFuiuiuU)
GO(glTextureStorageMem1DEXT, vFuiuiuU)

// GL_EXT_semaphore
GO(glGenSemaphoresEXT, vFip)
GO(glDeleteSemaphoresEXT, vFip)
GO(glIsSemaphoreEXT, CFu)
GO(glSemaphoreParameterui64vEXT, vFuup)
GO(glGetSemaphoreParameterui64vEXT, vFuup)
GO(glWaitSemaphoreEXT, vFuupupp)
GO(glSignalSemaphoreEXT, vFuupupp)

// GL_EXT_memory_object_fd
GO(glImportMemoryFdEXT, vFuUui)

// GL_KHR_parallel_shader_compile
GO(glMaxShaderCompilerThreadsKHR, vFu)

// GL_AMD_framebuffer_multisample_advanced
GO(glRenderbufferStorageMultisampleAdvancedAMD, vFuiiuii)
GO(glNamedRenderbufferStorageMultisampleAdvancedAMD, vFuiiuii)

// GL_EXT_semaphore_fd
GO(glImportSemaphoreFdEXT, vFuui)

// GLX_SGI_make_current_read
GO(glXMakeCurrentReadSGI, iFpppp)
GO(glXGetCurrentReadDrawableSGI, pFv)

// GL_IMG_multisampled_render_to_texture
GO(glFramebufferTexture2DMultisampleIMG, vFiiiuil)
GO(glRenderbufferStorageMultisampleIMG, vFilill)

// GL_ANGLE_translated_shader_source
GO(glGetTranslatedShaderSourceANGLE, vFulpp)

// GL_EXT_EGL_image_storage
GO(glEGLImageTargetTexStorageEXT, vFupp)
GO(glEGLImageTargetTextureStorageEXT, vFupp)

// GL_EXT_external_buffer
GO(glBufferStorageExternalEXT, vFullpu)
GO(glNamedBufferStorageExternalEXT, vFullpu)

// GL_EXT_memory_object_win32
GO(glImportMemoryWin32HandleEXT, vFuUup)
GO(glImportMemoryWin32NameEXT, vFuUup)

// GL_EXT_semaphore_win32
GO(glImportSemaphoreWin32HandleEXT, vFuup)
GO(glImportSemaphoreWin32NameEXT, vFuup)

// GL_EXT_shader_framebuffer_fetch_non_coherent
GO(glFramebufferFetchBarrierEXT, vFv)

// GL_EXT_win32_keyed_mutex
GO(glAcquireKeyedMutexWin32EXT, CFuUu)
GO(glReleaseKeyedMutexWin32EXT, CFuU)

// GL_INTEL_framebuffer_CMAA
GO(glApplyFramebufferAttachmentCMAAINTEL, vFv)

// GL_NV_alpha_to_coverage_dither_control
GO(glAlphaToCoverageDitherControlNV, vFu)

// GL_NV_clip_space_w_scaling
GO(glViewportPositionWScaleNV, vFuff)

// GL_NV_conservative_raster_dilate
GO(glConservativeRasterParameterfNV, vFuf)

// GL_NV_conservative_raster_pre_snap_triangles
GO(glConservativeRasterParameteriNV, vFui)

// GL_NV_draw_vulkan_image
GO(glDrawVkImageNV, vFUufffffffff)
GOM(glGetVkProcAddrNV, pFEp)
GO(glWaitVkSemaphoreNV, vFU)
GO(glSignalVkSemaphoreNV, vFU)
GO(glSignalVkFenceNV, vFU)

// GL_NV_gpu_multicast
GO(glRenderGpuMaskNV, vFu)
GO(glMulticastBufferSubDataNV, vFuullp)
GO(glMulticastCopyBufferSubDataNV, vFuuuulll)
GO(glMulticastCopyImageSubDataNV, vFuuuuiiiiuuiiiiiii)
GO(glMulticastBlitFramebufferNV, vFuuiiiiiiiiuu)
GO(glMulticastFramebufferSampleLocationsfvNV, vFuuuip)
GO(glMulticastBarrierNV, vFv)
GO(glMulticastWaitSyncNV, vFuu)
GO(glMulticastGetQueryObjectivNV, vFuuup)
GO(glMulticastGetQueryObjectuivNV, vFuuup)
GO(glMulticastGetQueryObjecti64vNV, vFuuup)
GO(glMulticastGetQueryObjectui64vNV, vFuuup)

// GL_NV_memory_attachment
GO(glGetMemoryObjectDetachedResourcesuivNV, vFuuiip)
GO(glResetMemoryObjectParameterNV, vFuu)
GO(glTexAttachMemoryNV, vFuuU)
GO(glBufferAttachMemoryNV, vFuuU)
GO(glTextureAttachMemoryNV, vFuuU)
GO(glNamedBufferAttachMemoryNV, vFuuU)

// GL_NV_mesh_shader
GO(glDrawMeshTasksNV, vFuu)
GO(glDrawMeshTasksIndirectNV, vFl)
GO(glMultiDrawMeshTasksIndirectNV, vFlii)
GO(glMultiDrawMeshTasksIndirectCountNV, vFllii)

// GL_NV_query_resource
GO(glQueryResourceNV, iFuiup)

// GL_NV_query_resource_tag
GO(glGenQueryResourceTagNV, vFip)
GO(glDeleteQueryResourceTagNV, vFip)
GO(glQueryResourceTagNV, vFip)

// GL_NV_scissor_exclusive
GO(glScissorExclusiveArrayvNV, vFuip)
GO(glScissorExclusiveNV, vFiiii)

// GL_NV_shading_rate_image
GO(glBindShadingRateImageNV, vFu)
GO(glShadingRateImagePaletteNV, vFuuip)
GO(glGetShadingRateImagePaletteNV, vFuup)
GO(glShadingRateImageBarrierNV, vFC)
GO(glShadingRateSampleOrderNV, vFu)
GO(glShadingRateSampleOrderCustomNV, vFuup)
GO(glGetShadingRateSampleLocationivNV, vFuuup)

// GL_NV_viewport_swizzle
GO(glViewportSwizzleNV, vFuuuuu)

// GL_OVR_multiview
GO(glFramebufferTextureMultiviewOVR, vFuuuiii)
GO(glNamedFramebufferTextureMultiviewOVR, vFuiuiil)

// GL_AMD_framebuffer_sample_positions
GO(glFramebufferSamplePositionsfvAMD, vFuuup)
GO(glNamedFramebufferSamplePositionsfvAMD, vFuuup)
GO(glGetFramebufferParameterfvAMD, vFuuuuip)
GO(glGetNamedFramebufferParameterfvAMD, vFuuuuip)

// GL_ANGLE_framebuffer_blit
GO(glBlitFramebufferANGLE, vFiiiiiiiiui)

// GL_ANGLE_framebuffer_multisample
GO(glRenderbufferStorageMultisampleANGLE, vFilill)

// GL_ANGLE_instanced_arrays
GO(glDrawArraysInstancedANGLE, vFiill)
GO(glDrawElementsInstancedANGLE, vFilipl)
GO(glVertexAttribDivisorANGLE, vFuu)

// GL_ANGLE_timer_query
GO(glBeginQueryANGLE, vFiu)
GO(glDeleteQueriesANGLE, vFlp)
GO(glEndQueryANGLE, vFi)
GO(glGenQueriesANGLE, vFlp)
GO(glGetQueryObjecti64vANGLE, vFuip)
GO(glGetQueryObjectivANGLE, vFuip)
GO(glGetQueryObjectui64vANGLE, vFuip)
GO(glGetQueryObjectuivANGLE, vFuip)
GO(glGetQueryivANGLE, vFiip)
GO(glIsQueryANGLE, iFu)
GO(glQueryCounterANGLE, vFui)

// GL_APPLE_copy_texture_levels
GO(glCopyTextureLevelsAPPLE, vFuuil)

// GL_APPLE_framebuffer_multisample
GO(glRenderbufferStorageMultisampleAPPLE, vFilill)

// GL_APPLE_sync
GO(glFenceSyncAPPLE, pFiu)
GO(glIsSyncAPPLE, iFp)
GO(glDeleteSyncAPPLE, vFp)
GO(glClientWaitSyncAPPLE, iFpuU)
GO(glWaitSyncAPPLE, vFpuU)
GO(glGetInteger64vAPPLE, vFip)
GO(glGetSyncivAPPLE, vFpilpp)

// GL_EXT_base_instance
GO(glDrawArraysInstancedBaseInstanceEXT, vFiillu)
GO(glDrawElementsInstancedBaseInstanceEXT, vFiliplu)
GO(glDrawElementsInstancedBaseVertexBaseInstanceEXT, vFilipliu)

// GL_EXT_blend_func_extended
GO(glBindFragDataLocationIndexedEXT, vFuuup)
GO(glGetProgramResourceLocationIndexEXT, iFuip)
GO(glGetFragDataIndexEXT, iFup)

// GL_EXT_buffer_storage
GO(glBufferStorageEXT, vFilpu)

// GL_EXT_clear_texture
GO(glClearTexImageEXT, vFuiiip)
GO(glClearTexSubImageEXT, vFuiiiillliip)

// GL_EXT_copy_image
GO(glCopyImageSubDataEXT, vFuiiiiiuiiiiilll)

// GL_EXT_draw_buffers
GO(glDrawBuffersEXT, vFlp)

// GL_EXT_draw_buffers_indexed
GO(glEnableiEXT, vFiu)
GO(glDisableiEXT, vFiu)
GO(glBlendEquationiEXT, vFui)
GO(glBlendEquationSeparateiEXT, vFuii)
GO(glBlendFunciEXT, vFuii)
GO(glBlendFuncSeparateiEXT, vFuiiii)
GO(glColorMaskiEXT, vFuiiii)
GO(glIsEnablediEXT, iFui)

// GL_EXT_draw_elements_base_vertex
GO(glDrawElementsBaseVertexEXT, vFilipi)
GO(glDrawRangeElementsBaseVertexEXT, vFilulipi)
GO(glDrawElementsInstancedBaseVertexEXT, vFilipli)

// GL_OES_draw_elements_base_vertex
GO(glDrawElementsBaseVertexOES, vFilipi)
GO(glDrawRangeElementsBaseVertexOES, vFiuulipi)
GO(glDrawElementsInstancedBaseVertexOES, vFilipli)
GO(glMultiDrawElementsBaseVertexEXT, vFipiplp)

// GL_EXT_fragment_lighting
GO(glFragmentLightModeliEXT, vFii)
GO(glFragmentLightModelfEXT, vFif)
GO(glFragmentLightModelivEXT, vFip)
GO(glFragmentLightModelfvEXT, vFip)
GO(glFragmentLightiEXT, vFiii)
GO(glFragmentLightfEXT, vFiif)
GO(glFragmentLightivEXT, vFiip)
GO(glFragmentLightfvEXT, vFiip)
GO(glGetFragmentLightivEXT, vFiip)
GO(glGetFragmentLightfvEXT, vFiip)
GO(glFragmentMaterialfEXT, vFiif)
GO(glFragmentMaterialiEXT, vFiii)
GO(glFragmentMaterialfvEXT, vFiip)
GO(glFragmentMaterialivEXT, vFiip)
GO(glFragmentColorMaterialEXT, vFii)
GO(glGetFragmentMaterialfvEXT, vFiip)
GO(glGetFragmentMaterialivEXT, vFiip)
GO(glLightEnviEXT, vFii)

// GL_EXT_instanced_arrays
GO(glVertexAttribDivisorEXT, vFuu)

// GL_EXT_map_buffer_range
GO(glMapBufferRangeEXT, pFillu)
GO(glFlushMappedBufferRangeEXT, vFill)

// GL_EXT_multi_draw_indirect
GO(glMultiDrawArraysIndirectEXT, vFipll)
GO(glMultiDrawElementsIndirectEXT, vFiipll)

// GL_EXT_multiview_draw_buffers
GO(glReadBufferIndexedEXT, vFii)
GO(glDrawBuffersIndexedEXT, vFipp)
GO(glGetIntegeri_vEXT, vFiup)

// GL_EXT_scene_marker
GO(glBeginSceneEXT, vFv)
GO(glEndSceneEXT, vFv)

// GL_EXT_shader_pixel_local_storage2
GO(glFramebufferPixelLocalStorageSizeEXT, vFul)
GO(glGetFramebufferPixelLocalStorageSizeEXT, lFu)
GO(glClearPixelLocalStorageuiEXT, vFllp)

// GL_EXT_sparse_texture
GO(glTexPageCommitmentEXT, vFiiiiillli)

// GL_EXT_texture_storage
GO(glTexStorage1DEXT, vFuiui)
GO(glTexStorage2DEXT, vFuiuii)
GO(glTexStorage3DEXT, vFuiuiii)

// GL_EXT_texture_view
GO(glTextureViewEXT, vFuiuiuuuu)

// GL_EXT_vertex_array_setXXX
GO(glCreateArraySetExt, pFv)
GO(glBindArraySetEXT, vFp)
GO(glDeleteArraySetsEXT, vFlp)

// GL_INTEL_texture_scissor
GO(glTexScissorINTEL, vFiff)
GO(glTexScissorFuncINTEL, vFiii)

// GL_NVX_linked_gpu_multicast
GO(glLGPUNamedBufferSubDataNVX, vFuullp)
GO(glLGPUCopyImageSubDataNVX, vFuuuuiiiiuuiiiiiii)
GO(glLGPUInterlockNVX, vFv)

// GL_NV_3dvision_settings
GO(glStereoParameteriNV, vFii)
GO(glStereoParameterfNV, vFif)

// GL_NV_copy_buffer
GO(glCopyBufferSubDataNV, vFiilll)

// GL_NV_draw_buffers
GO(glDrawBuffersNV, vFlp)

// GL_NV_draw_instanced
GO(glDrawArraysInstancedNV, vFiill)
GO(glDrawElementsInstancedNV, vFilipl)

// GL_NV_framebuffer_blit
GO(glBlitFramebufferNV, vFiiiiiiiiui)

// GL_NV_framebuffer_multisample
GO(glRenderbufferStorageMultisampleNV, vFilill)

// GL_NV_instanced_arrays
GO(glVertexAttribDivisorNV, vFuu)

// GL_NV_non_square_matrices
GO(glUniformMatrix2x3fvNV, vFilip)
GO(glUniformMatrix3x2fvNV, vFilip)
GO(glUniformMatrix2x4fvNV, vFilip)
GO(glUniformMatrix4x2fvNV, vFilip)
GO(glUniformMatrix3x4fvNV, vFilip)
GO(glUniformMatrix4x3fvNV, vFilip)

// GL_NV_polygon_mode
GO(glPolygonModeNV, vFii)

// GL_NV_texture_array
GO(glTexImage3DNV, vFiiillliiip)
GO(glTexSubImage3DNV, vFiiiiillliip)
GO(glCopyTexSubImage3DNV, vFiiiiiiill)
GO(glCompressedTexImage3DNV, vFiiilllilp)
GO(glCompressedTexSubImage3DNV, vFiiiiilllilp)
GO(glFramebufferTextureLayerNV, vFiiuii)

// GL_NV_viewport_array
GO(glViewportArrayvNV, vFulp)
GO(glViewportIndexedfNV, vFuffff)
GO(glViewportIndexedfvNV, vFup)
GO(glScissorArrayvNV, vFulp)
GO(glScissorIndexedNV, vFuiill)
GO(glScissorIndexedvNV, vFup)
GO(glDepthRangeArrayfvNV, vFulp)
GO(glDepthRangeIndexedfNV, vFuff)
GO(glGetFloati_vNV, vFiup)
GO(glEnableiNV, vFiu)
GO(glDisableiNV, vFiu)
GO(glIsEnablediNV, iFiu)

// GL_OVR_multiview_multisampled_render_to_texture
GO(glFramebufferTextureMultisampleMultiviewOVR, vFiiuilil)

// GL_QCOM_alpha_test
GO(glAlphaFuncQCOM, vFif)

// GL_QCOM_driver_control
GO(glGetDriverControlsQCOM, vFplp)
GO(glGetDriverControlStringQCOM, vFulpp)
GO(glEnableDriverControlQCOM, vFu)
GO(glDisableDriverControlQCOM, vFu)

// GL_QCOM_extended_get
GO(glExtGetTexturesQCOM, vFpip)
GO(glExtGetBuffersQCOM, vFpip)
GO(glExtGetRenderbuffersQCOM, vFpip)
GO(glExtGetFramebuffersQCOM, vFpip)
GO(glExtGetTexLevelParameterivQCOM, vFuiiip)
GO(glExtTexObjectStateOverrideiQCOM, vFiii)
GO(glExtGetTexSubImageQCOM, vFiiiiillliip)
GO(glExtGetBufferPointervQCOM, vFip)

// GL_QCOM_extended_get2
GO(glExtGetShadersQCOM, vFpip)
GO(glExtGetProgramsQCOM, vFpip)
GO(glExtIsProgramBinaryQCOM, iFu)
GO(glExtGetProgramBinarySourceQCOM, vFuipp)

// GL_QCOM_framebuffer_foveated
GO(glFramebufferFoveationConfigQCOM, vFuuuup)
GO(glFramebufferFoveationParametersQCOM, vFuuufffff)

// GL_QCOM_shader_framebuffer_fetch_noncoherent
GO(glFramebufferFetchBarrierQCOM, vFv)

// GL_QCOM_tiled_rendering
GO(glStartTilingQCOM, vFuuuuu)
GO(glEndTilingQCOM, vFu)

// GLES fixed point
GO(glAlphaFuncx, vFii)
GO(glClearColorx, vFiiii)
GO(glClearDepthx, vFi)
GO(glClipPlanex, vFip)
GO(glColor4x, vFiiii)
GO(glDepthRangex, vFii)
GO(glFogx, vFii)
GO(glFogxv, vFip)
GO(glFrustumx, vFiiiiii)
GO(glGetClipPlanex, vFip)
GO(glGetFixedv, vFip)
GO(glGetTexEnvxv, vFiip)
GO(glGetTexParameterxv, vFiip)
GO(glLightModelx, vFii)
GO(glLightModelxv, vFip)
GO(glLightx, vFiii)
GO(glLightxv, vFiip)
GO(glLineWidthx, vFi)
GO(glLoadMatrixx, vFp)
GO(glMaterialx, vFiii)
GO(glMaterialxv, vFiip)
GO(glMultMatrixx, vFp)
GO(glMultiTexCoord4x, vFiiiii)
GO(glNormal3x, vFiiii)
GO(glOrthox, vFiiiiii)
GO(glPointParameterxv, vFip)
GO(glPointSizex, vFi)
GO(glPolygonOffsetx, vFii)
GO(glRotatex, vFiiii)
GO(glScalex, vFiii)
GO(glTexEnvx, vFiii)
GO(glTexEnvxv, vFiip)
GO(glTexParameterx, vFiii)
GO(glTexParameterxv, vFiip)
GO(glTranslatex, vFiii)
GO(glAccumx, vFii)
GO(glBitmapx, vFlliiiip)
GO(glBlendColorx, vFiiii)
GO(glClearAccumx, vFiiii)
GO(glColor3x, vFiii)
GO(glColor3xv, vFp)
GO(glColor4xv, vFp)
GO(glConvolutionParameterx, vFiii)
GO(glConvolutionParameterxv, vFiip)
GO(glEvalCoord1x, vFi)
GO(glEvalCoord1xv, vFp)
GO(glEvalCoord2x, vFii)
GO(glEvalCoord2xv, vFp)
GO(glFeedbackBufferx, vFlip)
GO(glGetConvolutionParameterxv, vFiip)
GO(glGetHistogramParameterxv, vFiip)
GO(glGetLightx, vFiip)
GO(glGetMapxv, vFiip)
GO(glGetMaterialx, vFiii)
GO(glGetTexGenxv, vFiip)
GO(glGetTexLevelParameterxv, vFiiip)
GO(glIndexx, vFi)
GO(glIndexxv, vFp)
GO(glLoadTransposeMatrixx, vFp)
GO(glMap1x, vFiiiiii)
GO(glMap2x, vFiiiiiiiiii)
GO(glMapGrid1x, vFiii)
GO(glMapGrid2x, vFiiiii)
GO(glMultTransposeMatrixx, vFp)
GO(glMultiTexCoord1x, vFii)
GO(glMultiTexCoord1xv, vFip)
GO(glMultiTexCoord2x, vFiii)
GO(glMultiTexCoord2xv, vFip)
GO(glMultiTexCoord3x, vFiiii)
GO(glMultiTexCoord3xv, vFip)
GO(glMultiTexCoord4xv, vFip)
GO(glNormal3xv, vFp)
GO(glPassThroughx, vFi)
GO(glPixelM, vFiip)
GO(glPixelSto, vFii)
GO(glPixelTransferx, vFii)
GO(glPixelZoomx, vFii)
GO(glPrioritizeTexturesx, vFlpp)
GO(glRasterPos2x, vFii)
GO(glRasterPos2xv, vFp)
GO(glRasterPos3x, vFiii)
GO(glRasterPos3xv, vFp)
GO(glRasterPos4x, vFiiii)
GO(glRasterPos4xv, vFp)
GO(glRectx, vFiiii)
GO(glRectxv, vFpp)
GO(glTexCoord1x, vFi)
GO(glTexCoord1xv, vFp)
GO(glTexCoord2x, vFii)
GO(glTexCoord2xv, vFp)
GO(glTexCoord3x, vFiii)
GO(glTexCoord3xv, vFp)
GO(glTexCoord4x, vFiiii)
GO(glTexCoord4xv, vFp)
GO(glTexGenx, vFiii)
GO(glTexGenxv, vFiip)
GO(glVertex2x, vFi)
GO(glVertex2xv, vFp)
GO(glVertex3x, vFii)
GO(glVertex3xv, vFp)
GO(glVertex4x, vFiii)
GO(glVertex4xv, vFp)

// GL_OES_point_size
GO(glPointSizePointerOES, vFilp)

// GL_REGAL_error_string
GO(glErrorStringREGAL, pFi)

// GL_REGAL_extension_query
GO(glGetExtensionREGAL, iFp)
GO(glIsSupportedREGAL, iFp)

//glLogMessageCallbackREGAL
//glGetProcAddressREGAL

// GL_SGIS_multitexture
GO(glInterleavedTextureCoordSetsSGIS, vFi)
GO(glSelectTextureCoordSetSGIS, vFi)
GO(glSelectTextureSGIS, vFi)
GO(glSelectTextureTransformSGIS, vFi)

// GL_SGIS_shared_multisample
GO(glMultisampleSubRectPosSGIS, vFii)

// GL_SGIX_datapipe
GO(glAddressSpace, vFiu)
GO(glDataPipe, iFi)

// GL_SGIX_fog_layers
GO(glFogLayersSGIX, vFlp)
GO(glGetFogLayersSGIX, vFp)

// GL_SGIX_fog_texture
GO(glTextureFogSGIX, vFu)

// GL_ANGLE_request_extension
GO(glDisableExtensionANGLE, vFp)
GO(glRequestExtensionANGLE, vFp)

// GL_KHR_debug
GO(glDebugMessageControlKHR, vFiiilpi)
GO(glDebugMessageInsertKHR, vFiiuilp)
GOM(glDebugMessageCallbackKHR, vFEpp)
GO(glGetDebugMessageLogKHR, uFulpppppp)
GO(glPushDebugGroupKHR, vFiulp)
GO(glPopDebugGroupKHR, vFv)
GO(glObjectLabelKHR, vFiulp)
GO(glGetObjectLabelKHR, vFiulpp)
GO(glObjectPtrLabelKHR, vFplp)
GO(glGetObjectPtrLabelKHR, vFplpp)
GO(glGetPointervKHR, vFip)

// WGL_EXT_swap_control
GO(wglSwapIntervalEXT, iFi)
GO(wglGetSwapIntervalEXT, iFv)

// GL_MESA_framebuffer_flip_y
GO(glFramebufferParameteriMESA, vFuui)
GO(glGetFramebufferParameterivMESA, vFuup)

// GL_NVX_gpu_multicast2
GO(glUploadGpuMaskNVX, vFu)
GO(glMulticastViewportArrayvNVX, vFuuip)
GO(glMulticastViewportPositionWScaleNVX, vFuuff)
GO(glMulticastScissorArrayvNVX, vFuuip)
GO(glAsyncCopyBufferSubDataNVX, uFippuuuulllipp)
GO(glAsyncCopyImageSubDataNVX, uFippuuuuiiiiuuiiiiiiiipp)

// GL_NVX_progress_fence
GO(glCreateProgressFenceNVX, uFv)
GO(glSignalSemaphoreui64NVX, vFuipp)
GO(glWaitSemaphoreui64NVX, vFuipp)
GO(glClientWaitSemaphoreui64NVX, vFipp)

// GL_NV_memory_object_sparse
GO(glBufferPageCommitmentMemNV, vFulluUC)
GO(glTexPageCommitmentMemNV, vFuiiiiiiiiuUC)
GO(glNamedBufferPageCommitmentMemNV, vFulluUC)
GO(glTexturePageCommitmentMemNV, vFuiiiiiiiiuUC)

// GL_NV_vdpau_interop2
GO(glVDPAURegisterVideoSurfaceWithPictureStructureNV, lFpuipC)

// Base EGL
GO(eglBindAPI, iFi)
GO(eglBindTexImage, iFppi)
GO(eglChooseConfig, iFpppip)
GO(eglClientWaitSync, iFppiU)
GO(eglCopyBuffers, iFppp)
GO(eglCreateContext, pFpppp)
GO(eglCreateImage, pFppuup)
GO(eglCreatePbufferFromClientBuffer, pFpippp)
GO(eglCreatePbufferSurface, pFppp)
GO(eglCreatePixmapSurface, pFpppp)
GO(eglCreatePlatformPixmapSurface, pFpppp)
GO(eglCreatePlatformWindowSurface, pFpppp)
GO(eglCreateSync, pFpup)
GO(eglCreateWindowSurface, pFpppp)
GO(eglDestroyContext, iFpp)
GO(eglDestroyImage, iFpp)
GO(eglDestroySurface, iFpp)
GO(eglDestroySync, iFpp)
GO(eglGetConfigAttrib, iFppip)
GO(eglGetConfigs, iFppip)
GO(eglGetCurrentContext, pFv)
GO(eglGetCurrentDisplay, pFv)
GO(eglGetCurrentSurface, pFi)
GO(eglGetDisplay, pFp)
GO(eglGetError, iFv)
GO(eglGetPlatformDisplay, pFppp)
//GOM(eglGetProcAddress, pFEp)
GO(eglGetSyncAttrib, iFppip)
GO(eglInitialize, iFppp)
GO(eglMakeCurrent, iFpppp)
GO(eglQueryAPI, iFv)
GO(eglQueryContext, iFppip)
GO(eglQueryString, pFpi)
GO(eglQuerySurface, iFppip)
GO(eglReleaseTexImage, iFppi)
GO(eglReleaseThread, iFv)
GO(eglSurfaceAttrib, iFppii)
GO(eglSwapBuffers, iFpp)
GO(eglSwapInterval, iFpi)
GO(eglTerminate, iFp)
GO(eglWaitClient, iFv)
GO(eglWaitGL, iFv)
GO(eglWaitNative, iFi)
GO(eglWaitSync, iFppi)

// EGL_KHR_debug
GOM(eglDebugMessageControlKHR, iFEpp)
GO(eglQueryDebugKHR, iFip)
GO(eglLabelObjectKHR, iFpupp)

// EGL_MESA_image_dma_buf_export
GO(eglExportDMABUFImageQueryMESA, iFppppp)
GO(eglExportDMABUFImageMESA, iFppppp)

// EGL_ANGLE_sync_control_rate
GO(eglGetMscRateANGLE, iFpppp)

// EGL_CHROMIUM_sync_control
GO(eglGetSyncValuesCHROMIUM, iFppppp)

// EGL_EXT_device_query
GO(eglQueryDeviceAttribEXT, iFpip)
GO(eglQueryDeviceStringEXT, pFpi)
GO(eglQueryDisplayAttribEXT, iFpip)

// EGL_EXT_device_enumeration
GO(eglQueryDevicesEXT, iFipp)

// EGL_EXT_device_persistent_id
GO(eglQueryDeviceBinaryEXT, iFpiipp)

// EGL_EXT_image_dma_buf_import_modifiers
GO(eglQueryDmaBufFormatsEXT, iFpipp)
GO(eglQueryDmaBufModifiersEXT, iFpiippp)

// EGL_ANDROID_blob_cache
GOM(eglSetBlobCacheFuncsANDROID, vFEppp)

// EGL_KHR_swap_buffers_with_damage
GO(eglSwapBuffersWithDamageKHR, iFpppi)

// EGL_KHR_wait_sync
GO(eglWaitSyncKHR, iFppi)

// EGL_KHR_image_base
GO(eglCreateImageKHR, pFppupp)
GO(eglDestroyImageKHR, iFpp)

// EGL_KHR_fence_sync
GO(eglCreateSyncKHR, pFpup)
GO(eglDestroySyncKHR, iFpp)
GO(eglClientWaitSyncKHR, iFppiU)
GO(eglGetSyncAttribKHR, iFppip)

// EGL_ANDROID_native_fence_sync
GO(eglDupNativeFenceFDANDROID, iFpp)

// EGL_NV_post_sub_buffer
GO(eglPostSubBufferNV, iFppiiii)

// GL_EXT_clip_control
GO(glClipControlEXT, vFuu)

// GL_EXT_disjoint_timer_query
GO(glGenQueriesEXT, vFlp)
GO(glDeleteQueriesEXT, vFlp)
GO(glIsQueryEXT, iFu)
GO(glBeginQueryEXT, vFuu)
GO(glEndQueryEXT, vFu)
GO(glQueryCounterEXT, vFuu)
GO(glGetQueryivEXT, vFuup)
GO(glGetQueryObjectivEXT, vFuup)
GO(glGetQueryObjectuivEXT, vFuup)
GO(glGetQueryObjecti64vEXT, vFuup)
GO(glGetQueryObjectui64vEXT, vFuup)
GO(glGetInteger64vEXT, vFup)

// GL_OES_mapbuffer
GO(glGetBufferPointervOES, vFuup)
GO(glMapBufferOES, pFuu)
GO(glUnmapBufferOES, iFu)

// GLX_NV_copy_buffer
GO(glXCopyBufferSubDataNV, vFXppuulll)
GO(glXNamedCopyBufferSubDataNV, vFXppuulll)

// GLX_NV_delay_before_swap
GO(glXDelayBeforeSwapNV, iFXLf)

// GL_ARB_viewport_array
GO(glDepthRangeArraydvNV, vFuip)
GO(glDepthRangeIndexeddNV, vFudd)

GO(dummmy_vFppi, vFppi)
